package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(`*``!````F9H``#0```"XT@```@0`!30`(``)
M`"@`'``;``$``'`XQ```.$0!`#A$`0`(````"`````0````$````!@```#0`
M```T@```-(```"`!```@`0``!0````0````#````5`$``%2!``!4@0``&0``
M`!D````$`````0````$``````````(````"```!$Q```1,0```4`````@```
M`0```/3.``#TS@$`],X!`$`"``"$$@``!@````"````"`````,\```#/`0``
MSP$```$````!```&````!`````0```!P`0``<($``'"!``!$````1`````0`
M```$````4>5T9```````````````````````````!@````0```!2Y71D],X`
M`/3.`0#TS@$`#`$```P!```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````$`````$```!'3E4```````(````&````(`````0````4
M`````P```$=.50!@#B!&>,-4_Z2K%:T;A(+<H1YX`F$````%````(`````H`
M``"@$@`(`D01(``"0`!6`'`8P@@`,`@`%1$``!`"`"@`````````2`(@"@`*
M``2$`ZA`"$5@:0"$"3Y"/)<``0`()%B`!`E@#)-X"4):`$``0``!`$()`$"`
MC,"$```0D!"#"0`(`1"`@4!`P@F`+$"8`D$`(``@!`F`E`&D#I=V0`4`````
M````!@````<````)``````````````````````````H````,````#@```!``
M```1````$@```!0````7`````````!D``````````````!H````=````'@``
M```````B````(P```"0`````````)0```"8````J`````````"P`````````
M`````"T````N````+P```#``````````-````#4`````````.0``````````
M````.@```#T````^`````````#\```!`````0@```$0```!'`````````$H`
M``!+````3````$T`````````3@``````````````````````````````````
M`$\```!0`````````%(`````````5````%8```!8````````````````````
M`````%D```!=`````````%\`````````80````````!C````9```````````
M````9@```&<```!I````:@```&T```!?EI,<HUKOD%;;DQS#CH?_#3J7"])1
M!(2!=((->O!*:WU!CL5V5#R4S3\,K_<CSB")!W#3U&34?"%TL`(N3CWV9J_,
M9MOW`%X&I(?_`:\TZ+%(G>?@IP(*SDJN_\_>1RWC1\8!;'.%Q>P_D`+&#N`]
M/WZ6?,6)!9!AF.\2`2/YI)V[DQQ\[1$/AOF<@5#N$>-#1=7LNI63'%N:.P]!
M39U\I]VC:UGOEWDY\HL<#!3BGJ("]AG:S>.>!3*EA?NA;&`R8MOMZM/O#L@Y
M0!^YC?$.Z?O#PDHB??_LWI,<"XH05ZU+X\#9<5@<*]#A(BP.L7,;G]:]6#M`
M'\/E/RR8(M1HNN.2?"'_Y`Z*F-W";GII^HO9-5>3K01B-^/PP4/R[\C?A2!/
M5Z2;EL6YG$`PN((-41M]7[(!BV^_VE<;=F_C<+W02WUJ"4/6GR+'J"%B9`=^
MJ9R;8M#Z@NPL]HMK?YI\T)\L_(?PEGSN"U'Y\]O3'9!U@@U#9DL0!6RRS1;J
M6O$]K3D-H^#[2>)7Q!A7DEI2_=+O#RS?_DANQ=\??9`0Z2[%F[;(U;)QWZO*
MGP`````````````````````1```````````````@````(```````````````
M(````#0``````````````"````!0```````````````@````A`,``("8````
M````$@```$<"``!LEP```````!(```#>`@``))<````````2````P@(``-R7
M````````$@```+,$```DT0$``````"``%P#-`0``I)4````````2````NP(`
M`'28````````$@```+T!``"@E@```````!(```#6!```[>,``#`````2``T`
MX`,``#31`0``````$``8`'4"```PF````````!(```"@`@``W)8````````2
M````'@4``##1`0`$````$0`7`#4$``#IX```O`(``!(`#0`A`P``5)<`````
M```2````BP,``+"5````````$@```&\$``!%U@``K````!(`#0"&`@``2)<`
M```````2````,@,``$"6````````$@```.\#``!XX0$``````!``&``/`0``
M`)@````````2````600``!G4``"0````$@`-`(T$``#TE@```````!(```#R
M!```8=D``(@'```2``T`&`0``"W6```6````$@`-``X#```,F````````!(`
M``"6`0``0)@````````2````K0(``$R8````````$@```'`"``",F```````
M`!(```">`P``/-$!``0````A`!@`+P(```R7````````$@```#8"``"8F```
M`````!(```#0`@``T)8````````2````M0(``(R5````````$@```)X```"L
ME@```````!(```#K`@``D)<````````2````S0,``#31`0``````$``7`%8#
M``#4E0```````!(````I`@``,)<````````2````3P(``&26````````$@``
M`)\#```\T0$`!````"$`&`#Z`P``>.$!```````0`!@`*P,``$C1`0`$````
M$0`8`"4$``!QY````@```!(`#0!O`0``^)4````````2````Q@0``#'D``!`
M````$@`-`*$!```\EP```````!(```#_!```P=@``*`````2``T`MP0``)F:
M````````$@`-`"\$``!TY````````!(`#@"/`@``A)<````````2````P`0`
M`%25````````$@`+`+X```#0EP```````!(``````P``*)8````````2````
MR0(``)R7````````$@````(!``!,T0$``0```!$`&`"B!```?.0```0````1
M``\`U`,``#31`0``````$``8`%T#```8F````````!(```!J````E)8`````
M```2````=0,``+27````````$@```!P!``"XE@```````!(```"^!```I=,`
M`#`````2``T`.`$``("5````````$@````($``!XX0$``````!``&``1!0``
MK=0``'X!```2``T`TP```.R5````````$@```%X"``#$EP```````!(```"'
M````J)@````````2````%0(``'"6````````$@```*\!```8EP```````!(`
M``#A````M)@````````2````\P````"7````````$@```"T!```XT0$`!```
M`!$`&`"=`P``/-$!``0````1`!@`UP(```26````````$@```&$!```0E@``
M`````!(```!+!```>=@``#8````2``T`[@,``'CA`0``````$``8`!D#``"8
ME0```````!(```"O````Q)8````````2````L00``"31`0``````$``7`&<#
M```DF````````!(```"[`P``0-$!``0````1`!@`>P0``+'8```0````$@`-
M`.L!```TE@```````!(```#8`0``Z)<````````2````F`,``,&8``#8`0``
M$@`-`$(#```<E@```````!(````]`0``6)8````````2````.0,``/27````
M````$@```/8!``!0T0$`$P```!$`&`#Y`@``Z)8````````2````Y0(``*B7
M````````$@```'T"``!HF````````!(```!]`P``?)8````````2````Y`$`
M`'B7````````$@```"@%``#QU@``B`$``!(`#0!)`P``B)8````````2````
M0@$``&"7````````$@```*<"``!TE0```````!(```!_`0``X)4````````2
M````E@0``*7C``!(````$@`-`'@```!8F````````!(````'!```J=0```0`
M```2``T`3@$``+R5````````$@```(@!``!,E@```````!(`````;&EB<&5R
M;"YS;RXU+C$T`%]?9VUO;E]S=&%R=%]?`%]*=E]296=I<W1E<D-L87-S97,`
M7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%])5$U?<F5G:7-T97)434-L
M;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7W-A
M=F5?9&5S=')U8W1O<E]X`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U
M8W0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V
M7S)P=E]F;&%G<P!097)L7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N
M97=35G!V`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`
M4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`
M4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?9&]U;G=I;F0`4&5R;%]N
M97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A
M9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`
M4$Q?;65M;W)Y7W=R87``;&EB<'1H<F5A9"YS;RXP`'!T:')E861?9V5T<W!E
M8VEF:6,`8VQO<V4`;W!E;C8T`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!R
M96%D`&QI8F,N<V\N-@!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``
M7U]S=')D=7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD
M:7(`<F5A;&QO8P!A8F]R=`!M96UC:'(`9V5T<&ED`'-T<G1O:P!S=')L96X`
M;65M<V5T`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T
M<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R
M`&=E='5I9`!R96%D;&EN:P!E>&5C=G``7U]M96UC<'E?8VAK`'-T<F-H<@!R
M96%D9&ER-C0`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``
M7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`&QD+6QI;G5X+6%R;6AF+G-O
M+C,`7U]S=&%C:U]C:&M?9W5A<F0`7V5D871A`%]?8G-S7W-T87)T`%]?8G-S
M7W-T87)T7U\`7U]B<W-?96YD7U\`7U]E;F1?7P!?96YD`'!A<E]C=7)R96YT
M7V5X96,`<&%R7V)A<V5N86UE`%]?;&EB8U]C<W5?9FEN:0!84U]);G1E<FYA
M;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R
M;V,`<&%R7V1I<FYA;64`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R
M7V-L96%N=7``7TE/7W-T9&EN7W5S960`7U]D871A7W-T87)T`'AS7VEN:70`
M7U]L:6)C7V-S=5]I;FET`%A37TEN=&5R;F%L<U]005)?0TQ%05)35$%#2P!P
M87)?;6MT;7!D:7(`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`&UY
M7W!A<E]P;`!P87)?:6YI=%]E;G8`1TQ)0D-?,BXT`````````````````@`#
M``(``@`!`````@````$``0`"``(``0`!``(``@`!``(``@`!`````0`"``$`
M`0`"`````@`"``(``P`#``(``@````(``0`"``,``P`"``$``@`!`````0``
M``$``0`!``(``0````(``@````$``0`"`````@````$````!``$````"````
M`P````````````(``@````$``0`"`````0`"``0``0```````0`"``(``@``
M``(``@`"``(``@`!``(````"`````0````$```````$``0"G`P``$````"``
M```4:6D-```$`#4%`````````0`!``4"```0````(````!1I:0T```,`-04`
M```````!``$`5`(``!``````````%&EI#0```@`U!0```````"#1`0`5`0``
M.-$!`!1.```\T0$`%$\``$#1`0`46```2-$!`!0O``!,T0$`%#P``%#1`0`4
M8```#-`!`!9I```0T`$`%D0``!30`0`6)@``&-`!`!94```<T`$`%@H``"#0
M`0`6%```)-`!`!9N```HT`$`%@$``"S0`0`6*@``,-`!`!9J```TT`$`%D<`
M`#C0`0`6,0``/-`!`!90``!`T`$`%E$``$30`0`670``2-`!`!8Z``!,T`$`
M%EH``%#0`0`6%P``5-`!`!9O``!8T`$`%EX``%S0`0`6+```8-`!`!9*``!D
MT`$`%F0``&C0`0`69P``;-`!`!9```!PT`$`%@P``'30`0`6)P``>-`!`!9"
M``!\T`$`%E4``(#0`0`6)0``A-`!`!80``"(T`$`%F$``(S0`0`6&P``D-`!
M`!9-``"4T`$`%B,``)C0`0`62P``G-`!`!8'``"@T`$`%BL``*30`0`6,P``
MJ-`!`!86``"LT`$`%A,``+#0`0`6:```M-`!`!8&``"XT`$`%F4``+S0`0`6
M-P``P-`!`!8H``#$T`$`%CL``,C0`0`68@``S-`!`!9!``#0T`$`%D@``-30
M`0`6.0``V-`!`!8(``#<T`$`%EL``.#0`0`67P``Y-`!`!89``#HT`$`%AX`
M`.S0`0`6/P``\-`!`!97``#TT`$`%@\``/C0`0`6'P``_-`!`!8@````T0$`
M%FP```31`0`68P``"-$!`!8+```,T0$`%@4``!#1`0`6(0``%-$!`!8D```8
MT0$`%DD``!S1`0`63```"$`MZ5P!`.L(@+WH!.`MY03@G^4.X(_@"/"^Y9`Z
M`0``QH_B$\J,XI#ZO.4`QH_B$\J,XHCZO.4`QH_B$\J,XH#ZO.4`QH_B$\J,
MXGCZO.4`QH_B$\J,XG#ZO.4`QH_B$\J,XFCZO.4`QH_B$\J,XF#ZO.4`QH_B
M$\J,XECZO.4`QH_B$\J,XE#ZO.4`QH_B$\J,XDCZO.4`QH_B$\J,XD#ZO.4`
MQH_B$\J,XCCZO.4`QH_B$\J,XC#ZO.4`QH_B$\J,XBCZO.4`QH_B$\J,XB#Z
MO.4`QH_B$\J,XACZO.4`QH_B$\J,XA#ZO.4`QH_B$\J,X@CZO.4`QH_B$\J,
MX@#ZO.4`QH_B$\J,XOCYO.4`QH_B$\J,XO#YO.4`QH_B$\J,XNCYO.4`QH_B
M$\J,XN#YO.4`QH_B$\J,XMCYO.4`QH_B$\J,XM#YO.4`QH_B$\J,XLCYO.4`
MQH_B$\J,XL#YO.4`QH_B$\J,XKCYO.4`QH_B$\J,XK#YO.4`QH_B$\J,XJCY
MO.4`QH_B$\J,XJ#YO.4`QH_B$\J,XICYO.4`QH_B$\J,XI#YO.4`QH_B$\J,
MXHCYO.4`QH_B$\J,XH#YO.4`QH_B$\J,XGCYO.4`QH_B$\J,XG#YO.4`QH_B
M$\J,XFCYO.4`QH_B$\J,XF#YO.4`QH_B$\J,XECYO.4`QH_B$\J,XE#YO.4`
MQH_B$\J,XDCYO.4`QH_B$\J,XD#YO.4`QH_B$\J,XCCYO.4`QH_B$\J,XC#Y
MO.4`QH_B$\J,XBCYO.4`QH_B$\J,XB#YO.4`QH_B$\J,XACYO.4`QH_B$\J,
MXA#YO.5X1\!&`,:/XA/*C.($^;SE`,:/XA/*C.+\^+SE`,:/XA/*C.+T^+SE
M`,:/XA/*C.+L^+SE`,:/XA/*C.+D^+SE`,:/XA/*C.+<^+SE`,:/XA/*C.+4
M^+SE`,:/XA/*C.+,^+SE`,:/XA/*C.+$^+SE`,:/XA/*C.*\^+SE>$?`1@#&
MC^(3RHSBL/B\Y0#&C^(3RHSBJ/B\Y0#&C^(3RHSBH/B\Y7A'P$8`QH_B$\J,
MXI3XO.4`QH_B$\J,XHSXO.4`QH_B$\J,XH3XO.4`QH_B$\J,XGSXO.4`QH_B
M$\J,XG3XO.5X1\!&`,:/XA/*C.)H^+SE`,:/XA/*C.)@^+SE+>GP08BP!9`%
MJ`21!*D#D@.J__?"[TGRO%'`\@`!2?*L8,#R```*1@3PFOU-\DP3P/(!`QUX
M`"T`\(R`3?(X%,#R`00@:/_WM.Z0^$<D`T8@:$+P`@*#^$<D__>J[@6;G^U9
M:Y_M6GL%,P3ND#JX[F1;->X&:[3NQVOQ[A#ZD/A')$+P`0*`^$<D`/.0@)@`
M3O)<*/_W2.\$F4WR+!/`\@$#!9K`\@$(#&A=:`$JR+\.'T[V%`/(OP;K@@;`
M\@`#!T9.]A``/&#`\@``O6#(OP?Q#`1X8$_P!`#[8$CX\'Q(^/0,!=U1^`1?
ML4)$^`1?^=$"\8!%`"0#-0"46/CH#`,R.T9-\M4QP/(``4?X)4#_]^CM3O)<
M)<#R`04$1G"S6/CH#$[R7"7_]ZCN3O+`4`>IP/(``,#R`04#\(GZ(+-8^.@,
M__>\[?_W1.X@1@BPO>CP@?_W#NY.\EPCP/(!`T/XZ`QHLTWR.!3`\@$$__=*
M[B!H__<<[H#X!%1BYU7XZ`S_]\[M!$;*YU7X[`P0L03PJ/S4YP>I3O)<4,#R
M```#\%;Z1?CL#``HR=#PYT[R[&!-\E`1P/(``,#R`0'_]ZCN`2#_]P+O````
M`````````(#____/04_P``M/\``.7?@$&VI&3?@$+4WX!`W?^!3`3?@$S01(
M!$O_]WKM__=F[0``<>0``,&8```QY```%#"?Y10@G^4#,(_@`B"3YP``4N,>
M_R\!MO[_ZB`U`0`@`0``"+5-\C00!TO`\@$`&QH&*P#8"+U`\@`#P/(``P`K
M^-"81_;G-]$!``BU3?(T$$WR-!/`\@$`P/(!`QL:FQ`#Z]-S61``T0B]0/(`
M`L#R``(`*OC0D$?VYQ"U3?)C%,#R`00C>!NY__?+_P$C(W`0O4SV_&#`\@$`
M"+4#:"NQ0/(``\#R``,#L9A'O>@(0/_WR[\`ORWI\`^M];YM`/$X!=ZL`/%X
M!AN0&I;-Z3ZKU?@`P$_P``MK:`@US?A,L$_J'")/Z@PA0NH#8A\"`O1_0A*2
M&@X8"@'T?PH']'\(3^H<81\&3^H,;`#T?T`.D$KJ#`"41DCJ!P+=Z1)G0>H#
M(<WX/+`!\/\!,$,,D4OJ!P'=Z0YGS?@TL`SP_PPR0\WX0,!+Z@<#W?AHP-WI
M#&?-^$2P945`Z@8`0>H'`=WI$&=$Z0(!0NH&`D/J!P/DZ`0CK=$-]71Y#?5:
M?/JO#?5>>$`FZJ@2D!*9^>D"(_'I`D540%U`$I'XZ0(!_.D"(V!`:4!"0$M`
MD!@!/D_JTGI/\``"2NI#"@N20.H*``J0W>D*1>?I`D7>T1N?#?6^;-WX;+!D
MJ1N;U^D`9]OI"*O3Z00CS>D(9]WX((#=^"20S>D`JT_JV&3=^""@1.I)%-WX
M;)#=^&RP?.F@9T_J2A#9Z0*)($/-Z00CW>D`(]OI!JO-Z0:)MA@/]A1EU>D`
M14?K`P?=^!B`!)ND&<WI`JM%ZP<%W?@<H`/J"`/=^!20)!ADDT7Q``7=Z0(C
M">H*"=WI!F=/ZI@(S?B4D4CJBGC1Z0`!(NH&!B/J!P?=^!B@!D,/0Z`93_``
M!D7K!P'-Z0P!#)U/ZHIR0NH(`@`A%)7H#A660.I&$#J2")S=^"2`W?CHD-SI
M`B,&Z@@'">H$"<WXF)'=Z0*).Y88ZP((%)IGETGK`PG=Z01GW>D(14_J0AIF
MJD#J"@`FZ@0$)^H%!=+I`&<(FR9#+T,/]D!5U>D`1<WI#F>>"-WI#JL4ZP@$
M1>L)!=WX)(`4ZPH$"T9%ZPL%W?@@L$;JB'87D13K``A!D4_JBW(,F4+J!@)`
MDD":3^K89-WX-+!$ZD,4W.D$9P'J`@$+Z@,+:)'=Z3HC1?$`"=WI!`'-^*2Q
MW>D4JS88S?A8@$?K`0<BZ@H*%IIHJ<WI#HDCZ@L+T>D``4_J0A@/]JQ#T^D`
M(T3J"`1*Z@`*2^H!"[883_``"$?K`P<4FQ;K"@9/\``*1^L+!]WX4+"8"$#J
MB'`6ZP0(3^J+<D?Q``D"0]SI!F<-]8![S?A@@$*24$8/]EA%U>D`14.00IDV
M&0Z81^L%!\WX9*``)=WI%B,(0-OI`*MJJ0^<*NH"`BOJ`P/=Z3JK+$!JD&N4
M%NL*!M'I``%'ZPL'#?6$>P)#"T.T&-OI`*M'ZP,%W>D89]SI"`$JZ@8&#?6`
M>@_V\#/3Z0`C*^H'!\WI#F=/\``+VND`9Q(80^L!`]SI"@&V&,WI"D5'ZP,'
MS>D,9P_VP#?7Z0!G3^K89$3J2Q1/ZD@2@!E"KD'K!P$B0];I`*L/]IPWU^D`
M9QKK``I/\```2^L!"\WI$*O=Z0JK%ID:ZP(*W.D,(TOQ``L=D+883^J1!$?K
M`P=$ZH!TS>D*9P_V8#'1Z0`!W.D.9\WX<*"`&4'K!P$6G\WI.@$`($60N@=$
MKR)#1)((Z@(!">H``FR1#?78>=?I`&?=Z1Q%W>D*`6V2)NH$!-GI`(DGZ@4%
MS>D41388W>D.14?K`0?=Z0PC3^K:8$3J"`1%Z@D%I!@/]O`IV>D`B47K`P7<
MZ1`CS>D69P`G&.L""$#J1Q!/ZDH22>L#"0)#0*Z@&!B:1?$``1B='I!NJ\WI
M#`&0",;I`(DY1D#JAW`+Z@$(J@=&J1^7`D-'EPKJ`@=&DMWI'JO1Z0`!;I?-
M^+R!(.H*"M/I`",AZ@L+W>DZ1<WI&*O=Z12K)!C=Z1")1>L!!4KJ`@I+Z@,+
M&NL("AR;2^L)"]WX>)``(,WI%$4`(IP(3^K99I!&1NI`%D_J21`&0T3J@G0:
MZP8"2*U+\0`#S>D.(QR;()*2",WXA(!"ZHAR#)^8!]WX-+`@0\WX)($'0$B0
M"^H("W"7S?C$L0WUX'O=Z2!GU>D`1=OI`*LDZ@8&)>H'!]WI&$4@F$3J"@1%
MZ@L%W>D6J]WX@)`4ZPH$#IE%ZPL%PT9/ZH!XP`Y"Z@@"0.I+$$R23^I)$@)#
MV$:D&!Z:1?$`!<WX-+$%Z@L+'IV0"$-&0.J(<,WXC("J!\WX+($"0QA&#YL1
M0-WX,*$#Z@@##?7D>"*4!.H*"G*1<Y-*J]CI`$7=^(B0S?C0H31#S?C4L3U#
MW>D4JT_JV69*DD;J0!84ZPH$W?B(H-/I`",-]>AYW>DB`47K"P79Z0")(NH`
M`$_J2A(60R/J`0%(JD"K0.H(`!3K!@A!Z@D!1?$`"=/I`$72Z0`C#_;X!]?I
M`&>D&$JJ1>L#!0`90>L%`=SI$D7-^)"``".D&=+I`*M%ZP<%3*\:ZP0*)9-+
MZP4+U^D`9]WI)$5/ZMABS>D0JT+J0Q(FZ@0$)^H%!0_VJ`?7Z0!GS>D*1=SI
M%$6D&4RN1>L'!=;I`*L/]HP'U^D`9QKK!`I+ZP4+W.D61<WI%*M/\``*I!E/
M\``+1>L'!<WI&$5/ZD@4`"<B0\WI#*N$&$_J1QM/ZI0##)-!\0`%)I3-Z0Y%
M2^K4:T_J1!H,G#U&(IY$ZH5T#)0BG*D(L`@-D4#JA7!VJZ('3JD"0R>73I((
MZ@(&3Y4)Z@4'T>D``7:6=Y?=Z1AGT^D`1=WI"B,V&-WI)HE'ZP$'%$,DFB#J
M"`@AZ@D)W>D0`1U#S>D6B0`CW?B0D"08S>D89T_JD@!+Z@H&1>L!!4#J@W`4
MZP8*3^J)<LWXH*`.F4+J``)1DYA&*9,!Z@(!#YL-]:!Y>)%XJ5"21?$`"]WI
M*&<#Z@@#W>D617F3V>D`B='I``'=Z10C*.H&!BGJ!P<$0P_R:'G9Z0")#4/<
MZ1@!I!A%ZP,%S>D.9Q#K"``-]:!X0>L)`4_JVF+8Z0!G3_``"4+J21(/\C1Y
MV>D`B3883_```T?K`0?<Z1H!S>D09T_J2A80ZP@`0NH&`D'K"0&F&":<1?$`
M!P`B*Y)/ZD,9*I:B!]WI#$4`)0OJ!0,-]:1[(D-3E4GJUFE2D@KJ`@+=Z2I%
M3^I&&-OI`*MZDBKJ!`0KZ@4%S>D417JM&NL`"GN3W>D.(TOK`0O5Z0!%W>D8
M`2)#*T.`&$GJ"`)!ZP,!$.L"",WI%JM!\0`)S>D,B0`CS?BP@'RI*)H`)=WX
ML)`'Z@,(+95/ZH5[E`B0!T3J@W3-^/2!($-4D`;J``5\E=WI%$5+ZI8+T>D`
M`4_JAGI/ZMEFW>D0B01##4-4J13K"`0LFD7K"055DT;J0Q;1Z0`!W>DLB0R?
M(.H("%`!!D-+Z@H`W?@TL*(9#?7\>BZ21?$``\WI#B,`(POJ`PO-^/RQ!T#=
M^+BP(>H)"7Z7T@[:Z0!G0NI#$E:03^I+%-WI%@%&Z@@&(D-'Z@D'-A@ODU>3
M1^L!!P_RQ%O;Z0"K%NL""-SI'"-'\0`)+)P`)A+K"@(-]:AZ0^L+`]WXL+`Q
MEJ`(VND`9P`E3^J+=$_P``NV&$#JA7!'ZP,'3^I+$PWUK'L@0]WI+D5#ZMAC
MV^D`JT_J2!+-^,"`&D-8D"OJ!07=^#RP`"`.F2KJ!`0+Z@`+W?A@H<WX!+(-
M]0![`>H*`8"1V^D`JUBI69!$Z@H$1>H+!:09T>D``47K!P7=Z3!GW.D>JR#J
M!@8AZ@<'S>D*9Z881?$`!P_R!%75Z0!%W.D@(P`@%.L*!#*61>L+!0WUK'O-
MZ0QGV^D`JRZ>%.L*!#.01>L+!0_RU$O;Z0"KL`@2ZPH"#?6P>D/K"P-/\``+
MVND`9T#JBW!/\``+MA@RFD?K`P?-Z0YG`"9/ZI(*-T9*ZH9Z+IY;EPGJ!P%:
MKPWU`GFR!X.1`D-:D@CJ`@#7Z0!GW>DR(X*0)NH"`MGI`(DRF"?J`P/=Z0IG
MS>D0(P`B1NH(!D?J"0<V&4_JT&1$ZD(43^I`$$#J!``PG$?K!0<V&$_P``4T
MED_JE`(UE3"<0NJ%<@R93^I%&0V;1_$`!Z`'W>D010)#`"`10(21A*E=D`-`
MA9/1Z0`!2>K6:5R23^I&&-WI#B,$0PU#2>H(`!(9W?C(@$/K!0/-Z0HCW>D*
M14_JB'(D&#:4W?C8@$+J"@)/\``*!^H*"EJOW.DB`0;J`@E>DNVCT^D`(T7Q
M``77Z0!GS>D,10`D-Y02&%^43^K89$3J2Q0-];A[0^L!`Y(9S?@<HD/K!P/;
MZ0"KW>DT9\WX&)(KZ@<'#?4&>RKJ!@8VF-OI`*LTG4;J"@;=^-"@3^I`&$?J
M"P=/\``+MAA/ZIH`1.H(!$#JBW!/ZH5R1^L#!]SI)(D6ZP0*0NH``D_P``3-
M^."@.91'\0`+8))<JF&4#)M@GL6AT>D``3-`TND`9QCK``@-F$GK`0D6ZP@&
M1^L)!PWUO'G-Z0IG(4;9Z0")"$#=Z39G3^K:9(B31.I!%"GJ!P<-]0AYB9`H
MZ@8&V>D`B4_J2A`@0T;J"`;=^-B`1^H)!T_P``E/ZI@"0NJ)<MWI"HD6ZP@&
M1^L)!S081_$`!:6GU^D`9\WI#D5/\``)W.DF14_JF0/=^#B`3^J9`389S?B,
MD4?K!0?-Z0IG-I]@K=7I`$6X!]WI.&<DZ@8&)>H'!T+J``1#Z@(%S>D015ZM
M3^K88-7I`"-`ZDD0W>D*11(90^L%`\WI#",0F@OJ"06+E0KJ`@0-]0IZBI3:
MZ0!%8I)/ZD@2-$,]0]WI#&>D&4#J`@9%ZP<%%.L&"D7Q``O-Z12KW?C@L-SI
M*$5/ZIL`3^J+<D#JB7#=^%"00.H"!D'J``?-Z0QGW>D0JT_JV6#=Z0QG3^I)
M$H;J"@8/\L`;V^D`JQ3K"@1%ZPL%3_``"T#J2Q#=Z0ZK#?7`>P)#ANH*!MOI
M`*L4ZPH$1>L+!13K!@I%\0`+S>D.J]WI#@%/ZHAT`":`&$'Q``'-Z18!`"$6
MGXT'3^J1"T7JF`5+Z@4#1>H$`LWI#B/X#MWI#*M`ZD80W>D.17H!LP>$Z@H$
MA>H+!0_R/!O;Z0"K0^J9`\WI"D7<Z2I%%.L*!$7K"P7=Z0JKS>D21=WI%$6%
MZ@L%#?7$>X3J"@3-Z1!%V^D`J]WI$D7=^$"`%.L*!$7K"P44ZP@*0.H"!$7Q
M``L:ZP0`3^J)<DOQ``'-Z10!L0A#Z@((0>H#"<WI$(G=Z0XC-$;=Z1`!%)U0
M0%E`+:/3Z0`CS>D2`4_JU6K<Z2P!2NI&&D_J11B`&$CJ"@A!ZP,!W>D6(\WI
M"@'=Z1(!4$!90`R:S>D2`=WI"@$2FX`80?$``<`80?$``<WI#`'=Z0RKL0=!
MZI<!N`>S"!KK"`I#Z@$)0>H`",WI#(E+\0`+W>D0(]WI#`'-Z1:K4$!90`VC
MT^D`(\WI$@'<Z2X!%I^`&$'K`P'=Z10CS>D*`4_JUVK=Z1(!2NI&&@C@`+^9
M>8):`````*'KV6X`````3^I'&%!`64`.FDCJ"@C-Z1(!W>D*`1*;@!A!\0`!
MP!A!\0`!S>D.`=WI#JNQ!T'JE0&H![,(&NL("D/J`0E!Z@`(S>D.B4OQ``O=
MZ0PCW>D.`<WI%*M00%E`#_:\8]/I`"/-Z1(!W.DP`12=@!A!ZP,!W>D6(\WI
M"@%/ZM5JW>D2`4KJ1AI/ZD484$!90!":2.H*",WI$@'=Z0H!$IN`&$'Q``'`
M&$'Q``'-Z1`!W>D0J[$'0>J7`;@'&NL("D_JE@-#Z@$)2_$`"T'J``C-Z1:K
MS>D0B=WI#B/=Z1`!%I]00%E`#_8P8]/I`"/-Z1(!3^K7:MSI,@%*ZD8:3^I'
M&(`82.H*"$'K`P'=Z10CS>D*`=WI$@%00%E`#)K-Z1(!W>D*`1*;@!A!\0`!
MP!A!\0`!S>D,`=WI#*NQ!T'JE0&H![,(&NL("D/J`0E!Z@`(S>D,B4OQ``O=
MZ1`CW>D,`<WI%*M00%E`#_:L4]/I`"/-Z1(!W.DT`12=@!A!ZP,!W>D6(\WI
M"@%/ZM5JW>D2`4KJ1AI/ZD484$!90`Z:2.H*",WI$@'=Z0H!$IN`&$'Q``'`
M&$'Q``'-Z0X!W>D.J[$'0>J7`;@'&NL("D_JE@-+\0`+S>D6JQ:?0^H!"4'J
M``C-Z0Z)W>D,(]WI#@%/ZM=J2NI&&D_J1QA00%E`#_884]/I`"-(Z@H(S>D2
M`=SI-@&`&$'K`P'=Z10CS>D*`=WI$@%00%E`$)K-Z1(!W>D*`1*;@!A!\0`!
MP!A!\0`!S>D0`=WI$*NQ!T'JE0&H![,(&NL("D/J`0E!Z@`(S>D0B4OQ``O=
MZ0XCW>D0`<WI%*M00%E`#_:@0]/I`"/-Z1(!W.DX`12=@!A!ZP,!W>D6(\WI
M"@%/ZM5JW>D2`4KJ1AI/ZD484$!90`R:2.H*",WI$@'=Z0H!$IN`&$'Q``'`
M&$'Q``'-Z0P!W>D,J[$'0>J7`;@'LP@:ZP@*0^H!"4'J``C-Z0R)2_$`"]WI
M$"/=Z0P!S>D6JQ:?4$!90`_V&$/3Z0`CS>D2`=SI.@%/ZM=J2NI&&D_J1QB`
M&$CJ"@A!ZP,!W>D4(\WI"@'=Z1(!4$!90`Z:S>D2`=WI"@$2FX`80?$``<`8
M0?$``<WI#@'=Z0ZKL0=!ZI4!J`>S"!KK"`I#Z@$)0>H`",WI#HE+\0`+W>D,
M(]WI#@'-Z12K4$!90`_VE#/3Z0`CS>D2`=SI/`$4G8`80>L#`=WI%B/-Z0H!
M3^K5:MWI$@%*ZD8:3^I%&%!`64`0FDCJ"@C-Z1(!W>D*`1*;@!A!\0`!P!A!
M\0`!S>D0`=WI$*NQ!T'JEP&X![,(&NL("MSI/F=#Z@$)0>H`",WI$(G=Z0XC
M2_$`"]WI$`'-Z1:KS>D89U!`%I]90`_V!#/3Z0`C)D;-Z1(!W>D8`4_JUVK=
M^##`2NI$&H`83^I'&$'K`P'=Z10CS>D*`4CJ"@C=Z1(!4$#=Z0HC$NL,`@WU
MCFQ#\0`#$AA#\0`#S>D,(]WI#`&C"!#K"`!!\0`!S>D4`:$'J`=!ZI4!W.D`
M14/J`0E!Z@`(S>D,B=WI$"/=Z0P!S>D8131&4$!90`_V="/3Z0`CS>D2`=WI
M&`'=^#C`@!@4G4'K`P'=Z18CS>D*`=WI$@%/ZM5J2NI&&D_J11A00-WI"B-(
MZ@H($NL,`@WUCVQ#\0`#$AA#\0`#S>D.(]WI#@&S"!#K"`!!\0`!S>D6`;$'
MN`=!ZI<!W.D`9T/J`0E!Z@`(S>D.B=WI#"/=Z0X!S>D89R9&4$!90`_VY!/3
MZ0`CS>D2`=WI&`$6GX`80>L#`<WI"@'=Z1(!3^K7:MWI%"-*ZD0:W?A`P$_J
M1QA00-WI"B-(Z@H($NL,`@WUD&Q#\0`#$AA#\0`#S>D0(]WI$`&C"!#K"`!!
M\0`!S>D4`:$'J`=!ZI4!W.D`14/J`0E!Z@`(S>D0B=WI#B/=Z1`!S>D8131&
M4$!90`_V5!/3Z0`CS>D2`=WI&`'=^##`@!@4G4'K`P'=Z18CS>D*`=WI$@%/
MZM5J2NI&&D_J11A00-WI"B-(Z@H($NL,`@WUD6Q#\0`#$AA#\0`#S>D,(]WI
M#`&S"!#K"`!!\0`!S>D6`;$'N`=!ZI<!W.D`9T/J`0E!Z@`(S>D,B=WI$"/=
MZ0P!S>D89R9&4$!90`_VQ`/3Z0`CS>D2`=WI&`$6GX`8W?@XP$'K`P'=Z10C
MS>D*`4_JUVK=Z1(!2NI$&D_J1QA00-WI"B-(Z@H($NL,`@WUDFQ#\0`#$AA#
M\0`#S>D.(]WI#@&C"!#K"`!!\0`!S>D8`:$'J`=!ZI4!W.D`14/J`0E!Z@`(
MS>D.B=WI#"/=Z0X!S>D4131&4$!90`_V-`/3Z0`CS>D2`=WI%`'=^$#`@!@8
MG4'K`P'=Z18CS>D*`=WI$@%/ZM5J2NI&&D_J11A00-WI"B-(Z@H($NL,`@WU
MDVQ#\0`#$AA#\0`#S>D0(]WI$`&S"!#K"`!!\0`!S>D0`;$'N`=!ZI<!W.D`
M9T/J`0E!Z@`(S>D4B=WI#B/=Z10!S>D69R9&4$!90`_RI'/3Z0`CS>D2`=WI
M%@'=^##`@!@0GT'K`P'=Z1@CS>D*`=WI$@%/ZM=J2NI$&D_J1QA00-WI"B-(
MZ@H($NL,`@WUE&Q#\0`#$AA#\0`#S>D,(]WI#`&C"!#K"`!!\0`!S>D<`:$'
MJ`=!ZI4!W.D`14/J`0E!Z@`(S>D6B=WI%"/=Z18!S>D,15!`64`/\A1ST^D`
M(\WI$@'=Z0P!W?@XP(`8')U!ZP,!W>D0(\WI"@'=Z1(!3^K5:DKJ1AI/ZD48
M4$#=Z0HC2.H*"!+K#`(-]95L0_$``Q(80_$``\WI#"/=Z0P!LP@0ZP@`W.D`
MB4'Q``'-Z1@!L0>X!T'JEP$8GT/J`0M!Z@`*S>D0J]WI$`%/ZM=KW>D6(T_J
M1QS-^#C`M$900`_R?&/3Z0`C$NL(`DOJ1AC=Z1RK0^L)`\WX,(!/ZM9K@.H*
M`-WX4*#-^#R`$NL*",WX-+!#\0`)S>D*B=WI"B-/ZH9[2^J5"T_JE@D2&-WI
M#@%#\0`#S>D4(]WI#"-/ZH5Z2>H+!4OJ"@0"0]WI%`$-]99C@!A!\0`!S>D4
M`=WI$(G=^$"P1.H(`,WI#$73Z0`C!.H+"P?J``3-^#BRC)1%Z@D!#_+@6]OI
M`*L9G!+K"@+=^%"`!.H!!(V4%IQ#ZPL#W?@TL$_JV&42ZP0*CJH+Z@D+S?@\
MLD/Q``N,J\WI#JM%ZD85T^D`JT_J2!#2Z0`C#?6780J52NH""DOJ`PO-Z1:K
M\P[=Z0Y%3^J&>]WX6)!+ZI<+"Y-/ZH=Z%.L)!$_JE@-%\0`%S>D.1=WI"D5#
MZ@L'2^H*!MWI#*L@0]WI#D7-Z0YG)!C1Z0`C1?$`!<WI%D4.G4;J"@`(Z@`)
MS?A`D@7J"@62E0_R'%75Z0!%1^H+`=WX5)`2&1:?0^L%`P^=">H!"0WUF&$%
MZ@L%DY7-^$223^K7:MWX0)!*ZDP:S?@HH'@!$NL)!)*J0_$`!9"KT^D`J]+I
M`"-*Z@(*2^H#"\WI$*M/ZMQCW?A`D$_JC'L+DTOJF`L4ZPD$3^J<`T7Q``7-
MZ11%W>D*14_JB'I#Z@L)2^H*""!#W>D41=WI#JO-Z1"))!A%\0`%S>D411"=
M2.H*`-'I`"-)Z@L!!>H*!0?J``F6E<WX4)(/\EA%U>D`1=WX7)`2&=WX4(`)
MZ@$)S?A4DMWX,)!#ZP4#$9U/ZMAJ$NL)!):J!>H+!9>50_$`!92K2NI,&LWX
M**#3Z0"K3^I($-+I`",-]9EA2NH""DOJ`PO-Z0RK3^K<8]WX,)!/ZHQ["Y-+
MZI<+%.L)!$_JAWI%\0`%S>D61=WI"D5/ZIP#0^H+!TOJ"@8@0]WI%D4D&$7Q
M``7-Z19%S>D,9]WI$*L,G4;J"@#1Z0`C".H`"07J"@7-^&"21^H+`=WX5)":
ME>2EU>D`10GJ`0G-^&22#?6:8=WX.)`2&1:?0^L%`PV=$NL)!)JJ!>H+!9N5
M0_$`!9BK3^K7:G@!2NI,&LWX**#3Z0"KTND`(TKJ`@I+Z@,+S>D.JT_JW&/=
M^#B03^J,>PN32^J8"Q3K"01/ZIP#1?$`!<WI%$7=Z0I%3^J(>D/J"PE+Z@H(
M($/=Z11%W>D,J\WI#HDD&$7Q``7-Z11%#IU(Z@H`T>D`(TGJ"P$%Z@H%!^H`
M"9Z5S?APDK:EU>D`1=WX7)`2&=WX4(`)Z@$)S?ATDMWX0)!#ZP4##YU/ZMAJ
M$NL)!)ZJ!>H+!9^50_$`!9RK2NI,&LWX**#3Z0"K3^I($-+I`",-]9MA2NH"
M"DOJ`PO-Z1"K3^K<8]WX0)!/ZHQ["Y-+ZI<+%.L)!$_JAWI%\0`%S>D61=WI
M"D5/ZIP#0^H+!TOJ"@8@0]WI%D7=Z0ZKS>D09R081?$`!<WI%D40G4;J"@#1
MZ0`C".H`"07J"@7-^("2HI5'Z@L!W?A4D(2EU>D`10GJ`0G-^(22$AG=^#"0
M%I]#ZP4#$9T2ZPD$HJH-]9QA!>H+!:.50_$`!:"K3^K7:G@!2NI,&LWX**#3
MZ0"KTND`(TKJ`@I+Z@,+S>D,JT_JW&/=^#"03^J,>PN32^J8"Q3K"01/ZIP#
M1?$`!<WI%$7=Z0I%3^J(>D/J"PE+Z@H(($/=Z11%W>D0JR08S>D,B47Q``7-
MZ11%#)U(Z@H`T>D`(TGJ"P'=^%"`!^H`"07J"@6FE<WXD))5I=7I`$5/ZMAJ
MW?A<D$KJ3!H2&<WX**`)Z@$)S?B4DMWX.)!#ZP4##9U/ZD@0$NL)!*:J!>H+
M!:>50_$`!:2K#?6=8=/I`*O2Z0`C2NH""DOJ`PO-Z0ZK3^K<8]WX.)!/ZHQ[
M"Y-+ZI<+%.L)!$_JAWI%\0`%S>D61=WI"D5/ZIP#0^H+!TOJ"@8@0]WI%D7=
MZ0RKS>D.9R081?$`!<WI%D4.G4;J"@#1Z0`C".H`"07J"@7-^*"2JI5'Z@L!
M):75Z0!%W?A4D!(9%I\)Z@$)S?BDDMWX0)!#ZP4##YU/ZM=J$NL)!*JJ!>H+
M!:N50_$`!:BK2NI,&LWX**#3Z0"K>`'2Z0`C#?6>84KJ`@I+Z@,+S>D0JT_J
MW&/=^$"03^J,>PN32^J8"Q3K"01/ZHAZ1?$`!<WI%$7=Z0I%3^J<`R!#W>D4
M12081?$`!0?@H>O9;@````#<O!N/`````,WI%$7=^%"`2^H*!$/J"P5/\``*
MT>D`(T_P``O=Z0X!S>D0JT_JV&K=^#BP($/-^$"@!^H`"03J"PO-^+BR#_;(
M:]OI`*LI0\WXL))/ZDP0W?A<D!+K"@)#ZPL#W?@\L`GJ`0D,F07J"PO-^+RR
M$NL!"MWX0+!`ZMABK*FNJ`N2S?BTDDOJ3!O-^$"P0_$`"]'I`"/0Z0`!`D,+
M0\WI#"-/ZMQAW?@PD$_J2!(1D4_JC',*DAKK"0!+\0`!W>D*J\WI%@'=Z1`!
M2NH`"DOJ`0O-Z0JK0^J7`=WI%JN_!PJ83^J<`Q.1&NL`"DOQ``O-Z1:K$I=/
M\``*W>D29T_P``O-Z1"K#D,?0\WI#&?=^#"P%I_=Z0P!"^H$"\WXR+(-]9]K
M($/[#@CJ``(0D["2*4/;Z0`C#_;06]OI`*L.F!+K"@+=^%2@0^L+`]WX-)`*
MZ@$*S?C$HA+K``I/\``"0_$`"P`CS>D2(["KLJH)Z@4)T^D``;2MS?C,DM+I
M`"/=^$"0$$,90\WI#@%)ZDP9S?@LD$_JW&/-^$"03^I'&<WX*)!/ZHQPW?@X
MD!.0$9,:ZPD`2_$``=WI"JO-Z10!3^J<`]WI$`%*Z@`*2^H!"\WI"JL*F-WI
M%*L3F1KK``I/\```0>J8`4OQ``L3D4_JB'C-Z12KS?A(@-WI$HG=Z0RK2.H!
M"$GJ`PE(Z@H"S>D.B=WX4(!)Z@L#`"$-]:!KS>D*`0?J`@D.F<WXT)(!Z@H!
M3^K8:K:1S?@HH-OI``$/]LA+V^D`J]WX/)`0ZPH`W?@TH$'K"P'=^%RP">H*
M"1#K!`JVK,WXW)(+Z@,+S?C4LD'Q``O5Z0`!U.D`1<WI$*M/ZHQ[($,I0\WI
M%@%/ZMQEW>D0`4OJEPO=^%B03^J'>@J:2^H*!A#K"0`+E4+J3!(*DD'Q``'-
MZ1`!W>D*`4_J2!)/ZIP%`D/=Z1`!1>H+!\WI$&>`&-WI#JM!\0`!S>D6`0WU
MH6$0G1:?T>D`(P7J"@7=Z1`!NI5`Z@H`#_8(1=7I`$4(Z@`)S?C@DMWX5)!!
MZ@L!$AE/ZM=J">H!"<WXY)+=^#"00^L%`Q&=2NI,&A+K"02ZJ@7J"P6[E4/Q
M``6XJ\WX**!X`=/I`*O2Z0`C2NH""DOJ`PO-Z0RK3^K<8]WX,)!/ZHQ["Y-+
MZI@+%.L)!$_JG`-%\0`%3^J(>LWI%$5#Z@L)W>D*14OJ"@C-Z0R)#?6B:=WI
M$*L@0]WI#"/=Z11%#)E"Z@H")!A#Z@L#1?$`!0'J"@'-Z11%OI'9Z0!%!^H"
M"0_V0#'1Z0`!S?CPDMWX7)`D&-WX4(!%ZP$%">H#"<WX])+=^#B0#9E/ZMAJ
M%.L)`$KJ3!H!Z@L!OY%%\0`!S>D6`;RIOJC-^"B@3^I($M'I`*M/ZIP%T.D`
M`4KJ``I+Z@$+3^K<8<WI#JL+D4_JC'O=Z18!2^J7"]WX.)!/ZH=Z2^H*!D7J
M"P<0ZPD`S>D.9T'Q``'-Z18!W>D*`=WI#*L"0]WI%@$.G8`80?$``<WI%@$-
M]:-A!>H*!<*5T>D`(]WI#@$/]GPEU>D`14#J"@!!Z@L!".H`"<WX`)/=^%20
M$AD6GT/K!0,)Z@$)S?@$D]WX0)`/G4_JUVH2ZPD$PJH%Z@L%PY5#\0`%P*M*
MZDP:S?@HH-/I`*MX`=+I`"-*Z@(*2^H#"\WI$*M/ZMQCW?A`D$_JC'L+DTOJ
MF`L4ZPD$3^J<`T7Q``7-Z11%W>D*14_JB'I#Z@L)2^H*""!#S>D0B=WI%$4-
M]:1IW>D.J]WI$",D&!"91?$`!4+J"@+-Z11%W?A0@`'J"@'9Z0!%!^H""<:1
M0^H+`\WX$)-/ZMAJW?A<D$KJ3!H/]I@1T>D``4_J2!()Z@,)S?@4DR08W?@P
MD$7K`041F13K"0#-^"B@`>H+`<>11?$``<WI%@'$J<:H3^J<!='I`*O0Z0`!
M2NH`"DOJ`0O-Z0RK3^K<8=WX,)!/ZHQ["Y%+ZI<+W>D6`4_JAWI+Z@H&1>H+
M!Q#K"0#-Z0QG0?$``<WI%@'=Z0H!W>D0JP)#W>D6`0R=@!A!\0`!S>D6`0WU
MI6$%Z@H%RI71Z0`CW>D,`0_VZ`75Z0!%0.H*`$'J"P$(Z@`)S?@@D]WX5)`2
M&1:?0^L%`PGJ`0G-^"23W?@XD`V=3^K7:A+K"03*J@7J"P7+E4/Q``7(JTKJ
M3!K-^"B@T^D`JW@!TND`(TKJ`@I+Z@,+S>D.JT_JW&/=^#B03^J,>PN32^J8
M"Q3K"01/ZIP#1?$`!4_JB'K-Z11%0^H+"=WI"D5+Z@H(S>D.B0WUIFG=Z0RK
M($/=Z0XCW>D410Z90NH*`B080^H+`T7Q``4!Z@H!S>D41<Z1V>D`10?J`@D/
M]A@!T>D``<WX,)/=^%R0)!C=^%"`1>L!!0GJ`PG-^#23W?A`D`^93^K8:A3K
M"0!*ZDP:`>H+`<^11?$``<WI%@',J<ZHS?@HH$_J2!+1Z0"K3^J<!=#I``%*
MZ@`*2^H!"\WI$*M/ZMQAW?A`D$_JC'L+D4OJEPO=Z18!3^J'>DOJ"@9%Z@L'
M$.L)`,WI$&=!\0`!S>D6`=WI"@'=Z0ZK`D/=Z18!$)V`&$'Q``'-Z18!#?6G
M81:?!>H*!='I`"/=Z1`!TI5`Z@H`#_),==7I`$4(Z@`)S?A`D]WX5)!!Z@L!
M$AE/ZM=J">H!"<WX1)/=^#"00^L%`Q&=2NI,&A+K"032J@7J"P73E4/Q``70
MJ\WX**!X`=/I`*O2Z0`C2NH""DOJ`PO-Z0RK3^K<8]WX,)!/ZHQ["Y-+ZI@+
M%.L)!$_JG`-%\0`%3^J(>LWI%$5#Z@L)W>D*14OJ"@C-Z0R)#?6H:=WI$*L@
M0]WI#"/=Z11%#)E"Z@H")!A#Z@L#1?$`!0'J"@'-Z11%UI'9Z0!%!^H""0_R
MA&'1Z0`!S?A0D]WX7)`D&-WX4(!%ZP$%">H#"<WX5)/=^#B0#9E/ZMAJ%.L)
M`$KJ3!H!Z@L!UY%%\0`!S>D6`=2IUJC-^"B@3^I($M'I`*M/ZIP%T.D``4KJ
M``I+Z@$+3^K<8<WI#JL+D4_JC'O=Z18!2^J7"]WX.)!%Z@L#3^J'>MWI#$40
MZPD`0?$``<WI%@'=Z0H!`D/=Z18!@!A+Z@H"S>D.(T'Q``$K0\WI%@$.G0WU
MJ6$B0\WI"B/=^"B@)4#:E4_JG`/1Z0!%".H*"0_RL%'1Z0`!S?A@DR08W?@\
MD`V81>L!!169">H`"<WX;)/=^"R0%I\!Z@D!W?A`D-F1%.L)`-JL1?$``=BM
MS>D*`4_JUVK5Z0`!2NI,&M3I`$5Z`2!#W>D*12082NH"`$7Q``7-Z1!%W>D0
MJT_JC'5%ZI@%3^J(=!KK``I#Z@4!1>H$`,WI$`'=Z0Y%2_$`"]WI$"/-Z12K
M:T`-]:IEW?A0@&)`S>D*(]7I`",/\@Q5U>D`14_JV&!`ZDP03^I(&A(92NH`
M"D/K!0/=Z0I%S>D2(]WI%B-B0&M`#)W-Z18CW>D2(]WX6)!2&4/Q``,2ZPD$
M0_$`!13K"@!%\0`!S>D6`4_JC'&X!T'JEP%/ZIP#0^H!!T'J``;-Z0QG9$;=
MZ1`CW>D,`1:=64`-]:MC4$#-Z1(!T^D``4_JU6H/\GQ#T^D`(TKJ3!K=^#B0
M;@&`&$;J"@9!ZP,!W>D4(\WI"@'=Z1(!3^J,<4'JF`%00-WI"B,2ZPD"0_$`
M`Q(80_$``T_JB'#-Z0XC3^J<`]WI#JM#Z@$)0>H`",WI#HG=Z0PC&NL&"MWI
M#@%+\0`+S>D4JV9&64`-]:QC4$#-Z1(!T^D``4_JA'O]H]/I`",4GX`80>L#
M`=WI%B/-Z0H!3^K7:MWI$@%*ZDP:W?A`P$_J1QA00-WI"B-(Z@H($NL,`D/Q
M``,2&$/Q``/-Z1`CW>D0`:,(W?@PP!#K"`!!\0`!S>D6`:$'J`=!ZI4!%IU#
MZ@$)0>H`",WI$(G=Z0XC3^K5:MWI$`%*ZD0:3^I%&%E`#?6M8U!`S>D2`=/I
M``%(Z@H(UJ/3Z0`C@!A!ZP,!W>D4(\WI"@'=Z1(!4$#=Z0HC$NL,`MWX.,!#
M\0`#$AA#\0`#S>D,(]WI#`&C"!#K"`!!\0`!S>D4`:$'N`=!ZI<!%)]#Z@$)
M0>H`",WI#(G=Z1`C3^K7:MWI#`%*ZD0:3^I'&%E`#?6N8U!`S>D2`=/I``%(
MZ@H(M:/3Z0`C@!A!ZP,!W>D6(\WI"@'=Z1(!4$#=Z0HC$NL,`D/Q``,2&$/Q
M``/-Z0XCW>D.`:,($.L(`$'Q``'-Z18!H0>H!T'JE0$6G4/J`0E!Z@`(S>D.
MB=WI#"-/ZM5JW>D.`4KJ1!I/ZD4864`-]:]C4$#-Z1(!T^D``4CJ"@B5H]/I
M`"/=^$#`@!A!ZP,!W>D4(\WI"@'=Z1(!4$#=Z0HC$NL,`MWX,,!#\0`#$AA#
M\0`#S>D0(]WI$`&C"!#K"`!!\0`!S>D4`:$'N`=!ZI<!%)]#Z@$)0>H`",WI
M$(G=Z0XC3^K7:MWI$`%*ZD0:3^I'&%E`#?6P8U!`S>D2`=/I``%(Z@H(<Z/3
MZ0`C@!A!ZP,!W>D6(\WI"@'=Z1(!4$#=Z0HC$NL,`MWX.,!#\0`#$AA#\0`#
MS>D,(]WI#`&C"!#K"`!!\0`!S>D6`:$'J`=!ZI4!%IU#Z@$)0>H`",WI#(G=
MZ1`C3^K5:MWI#`%*ZD0:3^I%&%E`#?6Q8U!`S>D2`=/I``%(Z@H(4J/3Z0`C
M@!A!ZP,!W>D4(\WI"@'=Z1(!4$#=Z0HC$NL,`D/Q``,2&$/Q``/-Z0XCW>D.
M`:,(W?A`P!#K"`!!\0`!S>D4`:$'N`=!ZI<!%)]#Z@$)0>H`",WI#HG=Z0PC
M3^K7:MWI#@%*ZD0:3^I'&%E`#?6R8U!`S>D2`=/I``%(Z@H(,:/3Z0`C@!A!
MZP,!W>D6(\WI"@'=Z1(!4$#=Z0HC$NL,`MWX,,!#\0`#$AA#\0`#S>D0(]WI
M$`&C"!#K"`!!\0`!S>D6`:$'J`=!ZI4!%IU#Z@$)0>H`",WI$(G=Z0XC3^K5
M:MWI$`%*ZD0:3^I%&%E`#?6S8U!`S>D2`=/I``%(Z@H($*/3Z0`C@!A!ZP,!
MW>D4(\WI"@'=Z1(!4$#=Z0HC$NL,`D/Q``,2&$/Q``/-Z0PCW>D,`:,(">"O
M\P"`W+P;CP````#6P6+*`````!#K"`!!\0`!S>D4`:$'N`=!ZI<!%)]#Z@$)
M0>H`",WI#(G=Z1`C3^K7:MWI#`%*ZD0:3^I'&%E`#?6T8U!`S>D2`=/I``%(
MZ@H(#_)<4]/I`"/=^#C`@!A!ZP,!W>D6(\WI"@'=Z1(!4$#=Z0HC$NL,`MWX
M0,!#\0`#$AA#\0`#S>D.(]WI#@&C"!#K"`!!\0`!S>D6`:$'J`=!ZI4!%IU#
MZ@$)0>H`",WI#HG=Z0PC3^K5:MWI#@%*ZD0:3^I%&%E`#?6U8U!`S>D2`=/I
M``%(Z@H(#_+00]/I`".`&$'K`P'=Z10CS>D*`=WI$@%00-WI"B,2ZPP"W?@P
MP$/Q``,2&$/Q``/-Z1`CW>D0`:,($.L(`$'Q``'-Z10!H0>X!T'JEP$4GT/J
M`0E!Z@`(S>D0B=WI#B-/ZM=JW>D0`4KJ1!I/ZD<864`-];9C4$#-Z1(!T^D`
M`4CJ"@@/\DQ#T^D`(X`80>L#`=WI%B/-Z0H!W>D2`5!`W>D*(Q+K#`)#\0`#
M$AA#\0`#S>D,(]WI#`&C"-WX.,`0ZP@`0?$``<WI%@&A!Z@'0>J5`1:=0^H!
M"4'J``C-Z0R)W>D0(T_JU6K=Z0P!2NI$&D_J11A90`WUMV-00,WI$@'3Z0`!
M2.H*"/&CT^D`(X`80>L#`=WI%"/-Z0H!W>D2`5!`W>D*(Q+K#`+=^$#`0_$`
M`Q(80_$``\WI#B/=Z0X!HP@0ZP@`0?$``<WI%`&A![@'0>J7`12?0^H!"4'J
M``C-Z0Z)W>D,(T_JUVK=Z0X!2NI$&D_J1QA90`WUN&-00,WI$@'3Z0`!2.H*
M"-"CT^D`(X`80>L#`=WI%B/-Z0H!W>D2`5!`W>D*(Q+K#`)#\0`#$AA#\0`#
MS>D0(]WI$`&C"!#K"`!!\0`!S>D6`:$'J`=!ZI4!%IU#Z@$)0>H`",WI$(G=
MZ0XC3^K5:MWI$`%*ZD0:3^I%&%E`#?6Y8U!`S>D2`=/I``%(Z@H(L*/3Z0`C
MW?@PP(`80>L#`=WI%"/-Z0H!W>D2`5!`W>D*(Q+K#`+=^#C`0_$``Q(80_$`
M`\WI#"/=Z0P!HP@0ZP@`0?$``<WI%`&A![@'0>J7`12?0^H!"4'J``C-Z0R)
MW>D0(T_JUVK=Z0P!2NI$&D_J1QA90`WUNF-00,WI$@'3Z0`!2.H*"(ZCT^D`
M(X`80>L#`=WI%B/-Z0H!W>D2`5!`W>D*(Q+K#`+=^$#`0_$``Q(80_$``\WI
M#B/=Z0X!HP@0ZP@`0?$``<WI%@&A!Z@'0>J5`1:=0^H!"4'J``C-Z0Z)W>D,
M(T_JU6K=Z0X!2NI$&D_J11A+ZI4+64`-];MC4$#-Z1(!T^D``4CJ"@ALH]/I
M`".`&$'K`P'=Z10CS>D*`=WI$@%00-WI"B,2ZPP"0_$``Q(80_$``\WI$"/=
MZ1`!HPC=^##`$.L(`#V40?$``<WI%`&A![@'0>J7`12?0^H!"0WUO&-!Z@`(
MS>D0B=/I``%/ZM=J4J/3Z0`C2NI$&D_J1QB`&$CJ"@A!ZP,!W>D.(\WI"@%/
MZH5ZW>D0`:$(0>H+"0`D4$#=Z0HC`"7-Z1)%$NL,`D/Q``/-Z0HCW>D6(U!`
MW>D*(PWUO6,2&!+K"`)+Z@H(S>D,B4_JTFG=Z1"K/)+3Z0`!W>D,132CT^D`
M(X3J"@2%Z@L%@!C-Z19%0>L#`=WI%B/-Z0H!M0?=Z10!1>J7!<WX2)"\!T)`
M2T#=Z0H!1>H$"LWI%"/S#@Z:W?A(L-WX\,"`&!2:2^I&&Q.3S?A(L(`8W>D2
M(T_J3!@0F]WI`&="Z@@"@!C=Z0:)]AC=Z3Q%W?@PD``EW>D"(Q3K"`02ZPD"
MW>D(B1CK``C=Z00!$.L*`-WX;*#*^`"`RO@(0,KX&"#*^"!@RO@0`,KX!%#*
M^`Q0RO@44,KX'%#*^"10#?6^;;WH\`]P1P"_UL%BR@`````MZ?A#B48'1@`H
M.M!-\CP3P/(!`]/X`("X\0`/+M`&>#TN&+\`+@R_`"8!)A/1V/@`0&RQ148@
M1CE&,D;\]W#L$+FC73TK$-!5^`1/`"SRT2!&O>CX@T,<'D83^`$K/2H8OP`J
M^-'V&^'GR.L%!7`<($2M$,GX`%"]Z/B#0$:]Z/B#O>CX@P"_<+5-\CP5@K#`
M\@$%!D8P1@&I__>Q_YBQ`9PI:`'KA`-::$'X)"``*O'0FFA#^`0O`"KZT3!&
M`:G_]Y[_`"CKT0*P<+TMZ?!/#$8+>(.P!D8]*PB_3!P@1OSW;NL!J0=&,$;_
M]XG_!48`*%C0_/=DZX="1]D!FTWR/!G`\@$)3^J#"#5X/2T8OP`M#+\`)0$E
M"-!S'!U&$_@!&STI&+\`*?C1K1NX'-GX`)`H1$WR/!7\]Y;KP/(!!4GX"```
M*&C0*6@!FC-X4?@B$`MP:[$]*PO02APP1@'@/2L&T!#X`3\11@+X`3L`*_;1
M"D8](PMP%/@!.P+X`3\`*_G1`"`#L+WH\(\4^`$[!?@!.P`K]=`4^`$[!?@!
M.P`K\]'NYTWR/!G`\@$)V?@`H-KX`#!KLU-&4_@$+P$U`"KZT:D<B0!-\F03
MP/(!`QIH<K%01OSWLNO)^```X+%/ZH4(`T9J'``A0_@B$`&5B^<(1@$B&F#\
M]S;K@T9@L4_JA0A11D)&_/=,ZUM&R?@`L.CG'48((=;G3_#_,++G\+4$1IVP
M"+$#>`NY';#PO?SW*NH%1@`H^-`H1OSW9.L#1@#Q$P8@1@`K-=#:?"XJ*=#\
M][;J!T8P1OSWLNHX1`(P_/<"ZP$A3_#_,@"43O+P0P&6P/(``P=&_/=,ZSE&
M`R`"JOSWWNH!,#A&!=`&FP/T<$.S]8!/%M#\]YCJ.$;\]U+JR><:?0`JQM`N
M*M#16WT`*\'0S.<H1OSWONH@1OSWZNH=L/"]__>J_^?G`+]PM4WR.!3`\@$$
M(&C\]T#JT/B$,2!H76C\]SKJD/C\8R!H_/<VZ@;P?P9#:!N*P_,(`T;JPQ9N
M@"!H_/<JZM#XA#$@:%UH_/<DZ@`B3O8,`<#R``'\]^3JZ&$@:/SW&.K0^(0Q
M(&A=:/SW$NK0^/PT(&@K8OSW#.K0^(0Q(&A=:/SW!NK0^"PW*[$@:/SW`.K0
M^"PW&V]K8@`E(&C\]_CIT/B$,2!H6VB=8OSW\NG0^(0Q(&A;:)UA_/?JZ=#X
MA#$@:%QH_/?DZ=#XC#'C8G"].+5-\C@4P/(!!`5&(&C\]]CI*48`\6`"`R#\
M]Z#J"+$`(#B](&C\]\SI`V\#]'!#L_6`3PC0(&C\]\+I`V\#]'!#L_4@3^O1
M*$8"(?SWONG0\0$`.+\`(#B]`+_PM4WR0!2M]8!=P/(!!(.P!D8C:`WU@%4$
M-0]&3O+X0`&IP/(``$#V_W(K8/SW7.H`*"/=11X!JUI=ZK$%1@&H+R$J1OSW
MD.K`L4WR.!/`\@$#&&C\]X;I,48!JBM&_/?*Z0WU@%4$-2IH(VB:0A'1#?6`
M70.P\+T`+>#13?(X$\#R`0,8:/SW;NDQ1CI&_/<ZZ>;G_/?PZ4WR.!/`\@$#
M$+48:/SW7NE.\@A12?*@8D[R)%/`\@`!P/(``L#R``.]Z!!`_/<TNA"U3?(X
M%,#R`02"L"!H_/=&Z?_WW?\@:/SW0.D`(D[V#`,!DL#R``-.\C!1`)/`\@`!
M3O+I`L#R``+\]U3I`K`0O0"_<+5-\D`4K?4`7<#R`02&L"-H#?4`4A0R$V#\
M]]3I3O)44D[R2%/`\@`"P/(``P&2`2%!\@$"`)`#J/SWZ.D`*"+;#?6`40.H
M3_2`4A`Q_/?&Z04>&-MH'/SW@ND&1D"Q#?6`42I&$#'\]S+I,$8`(W-5#?4`
M4Q0S&F@C:)I"!=$-]0!=!K!PO0`@\N?\]V[I__>VORWI\$]-\D`7K?6!7<#R
M`0>!L`5&.V@-]8!2'#(.1D[R7%`&J<#R```38/_W&_TO(01&*$;\]WCHH+%.
M\FA0*4;`\@``__=T_2A&#?6`4QPS&F@[:)I"0/"0@`WU@5T!L+WH\(\H1OSW
MWNA.\GA1P/(``8-&,$;\]SSI@D8`*-S03O)864WR.!@'KL#R``G`\@$(3O*$
M4L#R``(%DIKX`#``*PB_RD8LL2!&44;\]Y+I`"A&T%!&_/>VZ`KK``,"1A/X
M`1PO*0?1`"`#^`$-`3H3^`$<+RGXT`$R6D2R]8!?J]H%F@$AS?@`H$[R?%,"
ME<#R``,!DC!&3_2`4OSW/.G8^```_/=>Z#%&`/%@`@,@_/?*Z$BYV/@``/SW
M5.@#;P/T<$.S]0!/%M!.\GA1`"#`\@`!_/?<Z()&NO$`#ZW1>^=.\GA1P/(`
M`?SWTNB"1KKQ``^BT7#G,$8!(?SW..@`*.+1,49.\FA0P/(``/_WW_PP1OSW
M(NEGY_SWKN@`OP-X.[%"'"\K"+\01A+X`3L`*_C1<$<`OQ"U!$:8LP-XB[/\
M]T#H`3@C&)Q"#-(B7"\J,M%:'@+@&7@O*2W1HD(31@+Q_S+WT:-"&+\#\?\S
M`]$5X!%X+RD$T9Q"&D8#\?\S]],2&Y,<L_6`7Q/8(48!,D_T@%,22/OWP.\0
M2!"]&W@O*Q31`B#\]V#H`T80L2XB&H`0O0`@$+U:'@+@&7@O*='0E$(31@+Q
M_S+WT\OG3O*$4,#R``"]Z!!`_/>\N&C1`0#PM4[R@$3`\@`$C;`"K4WR0!8/
MS,#R`08W:`_%#\P+ER1H#\5.\HA0P/(``"R`__<[_$[RE%#`\@``__<U_$[R
MG%#`\@``__<O_$[RJ%#`\@``__<I_$[RL%#`\@``__<C_$[RP%#`\@``__<=
M_$[R7%#`\@``__<7_$[RS%#`\@``__<1_$[RV%#`\@``__<+_$[RY%#`\@``
M__<%_$[R:%#`\@``__?_^T[R\%#`\@``__?Y^T[R_%#`\@``__?S^T[R"&`!
MJ<#R``#_]ZC[,+$!1D[RV%#`\@``__<&_$[R'&`!J<#R``#_]YG[,+$!1D[R
M,&#`\@``__?W^T[R/&`!J<#R``#_]XK[L+$!1D[R7%#`\@``__?H^T[RL%!.
M\FQAP/(``,#R``'_]][["YHS:)I")=$-L/"]3O),8`&IP/(``/_W:_LXL0%&
M3O+,4,#R``#_]\G[W^=.\F!A#?$9`,#R``$*(OOWZN\`*-313O+,4`WQ(P'`
M\@``__>U^\OG^_>&[Q"U3?(L%,#R`02"L"!H0QP!T`*P$+U.\LQ0`:G`\@``
M__<Z^R"Q`'@0L3`X&+\!("!@`K`0O0"_"+7[]\;N^_<>[P"Q`&@(O2WI\$,'
M1B5,C;`%K0_,#\64Z`<`!9R%Z`<`[+%.\GA8!:W`\@`(!>#[]QSON+%5^`1/
MC+$$J2!&__<*^SE&!D80L0-X`"OOT2!&.4;_]V;[5?@$3P`L[=$-L+WH\(,X
M1OOWUNZ!1C!&^_?2[DA$`C#[]R+O`)?-^`2``2$"ED_P_S).\GQ3P/(``X%&
M^_=J[R!&24;_]T+[R><`OZ3D``"+2RWI\$\%1I/H!P"M]0%-D;`#\0P&$J\#
M\20,&*Q-\D`9A^@'`,#R`0D/S@WQ5`[9^`"`S?@PD`WU`4D)\3P)#\26Z`,`
MR?@`@(3H`P"<Z`<`CN@'`!&I3O)<4,#R``#_]Z;Z!$88L0-X`"M`\(N!__=N
M_Q2L@$8`*%300$;[]WCN0``!,/OWR.Z8^``P!D8$1GNQ`),@1D[R>&,!(<#R
M``-/\/\R^_<.[QCX`3\"-``K[]$8F!BL&+D5X%3X!`^0L1&I__=T^H!&`"CV
MT`-X`"OST/_W//P`*._00$;[]Q3O@D8`*"[1$IQ4LR-X3_`!"#NY)>!7^"A`
M%+,C>`CQ`0CSL2!&__<C_``H\]`@1OOW^NX`*.[0@D84X/OW].X`*$#P+H%4
M^`0/`"@`\#&!$:G_]SWZ`"CUT`-X`"ORT.SG3_``"E!&3O*$6_OW$.[`\@`+
M!$8P1OOW"NX@1`#R!$0@1OOW6.X!(<WX`*!.\HQB`Y;`\@`"S?@$L$[R@&,"
MDL#R``-/\/\R@4;[]YKN2$9/].!Q^_<^[0$P,-!-\C@6P/(!!C!H^_>R[4E&
M`/%@`@,@^_=Z[@`H.]!-\D@1P/(!`2MH3O(4<@AHP/(``LWX`)`!(?OW+.X`
M(`WU`4D)\3P)V?@`(-WX,)#9^``PFD)`\+&"#?4!31&PO>CPC_OWFNX&:!$N
MR=!-\D@1P/(!`2MH3O*48@AHP/(``LWX`)`!(0&6^_<$[@`@UN<`O\#D```P
M:/OW;.T#;P/T<$.S]8!/NM$P:/OW8NV';_OW2.V'0K+1,&C[]UKM`V_#\P@#
ML_7@?ZG1($;[]];M$:F`1D[V8`#`\@``__>9^0`H`/!L@BQH^_=`[@%&($;_
M]UW\!$8`*`#P88(@1OOW:.T#*`9&$=T$.$[RT&$@1,#R``'[]S;N0+D$+@#P
MZ($F1!;X!3PO*P#PXH'_]R7^`48HN2!&^_=J[0V0`"A?T4[RS%!.\FQAP/(`
M`,#R``'_]\7Y3O8,!OOWPNW`\@`&S?@`D$[R\&/-^`2PP/(``P.6`2%/\/\R
M`"5/1@*00$;[]]+M%N#[]PCN`V@1*QG1^_>F[0$U3O(`<P"7(D8#E<WX!+#`
M\@`#!)8!(0*00$;[][KM0$9/].!Q^_=<[$(<!$;@T+E&2$;[]\CL049.\EQ0
MP/(``/_W@OE`1O_W\?U`1BSG@$9ZYO_WZ_T@1OOWO.TDYT[R<&@-(,#R``AS
MYD_P_S-O\!$"`B0`E/OW,.U/J0V8!B+[]Z;LG?@\,2.YG?@],4,K`/"3@0`D
M`"(`E``C#9C[]QSMXJ'1Z0`!XJ?7Z0!G#?'P#.*CT^D`(TR4S>DP`>&EU>D`
M1>&AT>D``<WI-&=F1LWI,B,`(@`CS>DV1<WI."/-Z3HCS>DN`<WX.(#-^#R0
M#9A/J4_T`$+[]VKLL/$`"D#S@H!/ZNIS3^K*``:04D;9`-WI.$5!ZEIYS?@<
MD-WI!@$`(0N1`!D*D-WI"@&I0@B_H$+=Z3I%`M(!-$7Q``51#TR:0>K#"=WI
M"@'-^""0S>DX`5D/"9'=Z0@!)!A%ZP$%S>DZ10`J3-#"\4`'`O$X`+I%N+]7
M1BZI"$1/J3I&^_=H[$R;.T1,DT`KL-%/JBZHQ^L*"A=$^_>L_KKQ/P\GW:KQ
M0`H'\8`(!_%`#$_JFAD(ZXD8K/%`!+9&(&@0-%3X#!QU1E3X""P.\1`.5/@$
M/&1%#\7QT2ZH^_>+_@3Q0`S$1>?1"?$!`ZKKB1H'ZX,7.48P1E)&2"/[]_SK
MS?@PH77G3Z_)YPVHD.@!`_OW1NPNJ3B<@"`ZG<3SQ0)3'!%$."N!^#@``O$Y
M``#SJX`NJ<+Q-P((1``A^_>:ZRZH*@XK#(WX*U&-^"]!+0J-^"@A(Z^-^"DQ
M(PZ-^"I1+:Z-^"PQ(PPD"HWX+3&-^"Y!^_=`_MWXN,`>K=WXP.`RF#293^H<
M1#::3^H<8XWX>\!/ZAPLC?AY0#Q&C?AZP$_J'FR-^'_@C?A\P$_J'DR-^(,`
M3^H>+HWXAQ"-^'[@3^H0;HWXBR"-^(#@3^H03HWX>#``"HWX@>!/ZA%NC?B"
M``@,C?B$X`D*3^H2;HWXA0"-^'W`$`R-^(80$@J-^(C@C?B)`(WXBB`!X!7X
M`3\`DR!&3O)X8P(TP/(``P$A3_#_,OOW-NRT0N_1S?@`D``DS?@$L$[V#`("
ME\#R``).\N!C`Y+`\@`#0$8!(4_P_S*'^"A`^_<<[&KF;6@`+3_T&JXH1OOW
M:NL#*'_V%*X$.$[RV&$H1,#R``'[]SCL`"@(ORQ&!^8NJ\+Q/P(81``A^_?N
MZBZH^_>M_0`C/),]DSZ3/Y-`DT&30I-#DT2319-&DT>32)-)DT'GG?@^,4$K
M?_1HKIWX/S%#*W_T8ZZ=^$`Q2"M_]%ZNG?A!,44K?_19KD_P_S,`E`V8;_`Y
M`OOW=.M/J0V8*2+[]^KJ3ZF-Z``*3O8,`@*1P/(``D[RX&,#DL#R``-`1@$A
M3_#_,OOWN.L%YOOW9.LL:)SEB:O-[P````!V5#(0`````/[<NI@`````\.'2
MPP`````!(T5G`````"WI\$]-\C@8P/(!"(6PV/@``/OWNNH!(P.I@/C],T[R
ML%#`\@``_O?__ABQ`W@Q*P#PZ8#_]^CZV/@``$[R7"?[]Z+J3O)H<0$BP/(`
M`0LCP/(!!_OW7.H`*$/05_CT/`)I`2O2^!B0/-U-\C@:`";`\@$*`20*X!EI
M6$;[]XSK5_CT/%B[`30!-J-")]W8^```^_=ZZDE&,D8`(_OWR.H%1@`H`/"H
M@`-H5_CP')IH4?@DL!+T@&+>T=KX```!DOOW8NH"(REH`9K[]X#K`4981OOW
M8NM7^/0\`"C3T%H>LD)QT-CX``!-\C@4^_=,ZD[R<'$!(L#R``$$(\#R`03[
M]P;J!49XL2!H^_<^ZBMI3O)T<L#R``(9:/OW!NHK:1MHFVA9`E_4V/@``$WR
M.!3[]RKJ3O)\<0$BP/(``00CP/(!!/OWY.D%1HBQ3O)H4`.IP/(``/[W9_X&
M1B!H`"Y[T/OW$NHK:3)&&6C[]]SIV/@````D^_<(ZDWR.!;`\@$&@/C]0]CX
M``#[]_[I`ZG`^'1%3O)<4,#R``!.\EPD_O="_L#R`02!1D?X[`QXLT_TX''[
M]VKI$2@"T$,<`2MQV`6PO>CPCP$KB]T!)-CX```!-/OWV.E)1OOWE.E7^/0\
MHT+SW'WG(&C[]\[I*VD9:/OW0NJ7YU?X]#Q:'K)"?_1PK^#G0W@`*S_T%:\1
MYU3X\`S_]S#[1/CL#``H/-`K:1EHBV@3](!D(-`(:5?X\$PA1OOW?NDJ:2=H
M%&BB:!+T@&D&1AS0(FE.\J1P.48S1L#R``#[]TCJ^_>6Z2II5_CP/!!H&6C^
M]]S_@.<P:/OWBNDI:2)&`B,):/OWINK5Y]CX``#[]X#I*6E*1@(C"6C[]YSJ
M`D;7YT[R@'#`\@``^_<BZE3X\!P#1DI&3O+,<,#R```):/OW%NHXM05&__=,
M^0-X!$8[L4(<+RL(OQ1&$O@!.P`K^-'_]UGZ6+%5L2MX0[%.\HQA($;`\@`!
M^_>DZ81"`-`XO2A&O>@X0/[WHKX0M4WR.!3`\@$$(&C[]SKI3_#_,?OW).D@
M:/OW-.E-\N$1`"+`\@`!O>@00/OW1+JO\P"``DM[1`.Q&VC[]\JY`NT``"WI
M^$,'1@Q.B$8,39%&?D3[]XCH?41V&[80"M`$/0`D`315^`0_.$9!1DI&F$>T
M0O;1O>CX@P"_MNH``*SJ``!P1P"_"$`MZ0B`O>@!``(`7U]%3E9?4$%27T-,
M14%.7U\@("`@("`@("`@("`@("``````0.@``%#H``!8Z```8.@``&CH``!\
MZ````````#CH``!8Y0```````##F```TY@``+.@``&#E```TZ````````!CH
M```@Z````````"5S+R5S````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z
M.F)O;W1?1'EN84QO861E<@!P97)L>'-I+F,```!);G1E<FYA;',Z.E!!4CHZ
M0D]/5``````O<')O8R\E:2\E<P!E>&4`+@```%!!4E]414U0`````%!!4E]0
M4D]'3D%-10`````Z````)7,E<R5S```O````4$523#5,24(`````4$523$Q)
M0@!015),-4]05`````!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!
M5TY%1`!005)?0TQ%04X```!005)?1$5"54<```!005)?0T%#2$4```!005)?
M05)'0P````!005)?05)'5E\P``!005)?1TQ/0D%,7T1%0E5'`````%!!4E]'
M3$]"04Q?5$U01$E2````4$%27U1-4$1)4@``4$%27T=,3T)!3%]414U0`%!!
M4E]'3$]"04Q?0TQ%04X`````4$%27T-,14%./0``,0```%-94U1%30``)3`R
M>``````E<R5S)7,E<P````!P87(M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV
M871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``'!A<FP`
M````+G!A<@`````E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P```"5S
M)7-T96UP+25U+25U)7,`````)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S
M(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O
M<&5R871I;VXI"@``05)'5@`````8````<&5R;``````P````56YA8FQE('1O
M(&-R96%T92!C86-H92!D:7)E8W1O<GD`````)7,Z(&5X96-U=&EO;B!O9B`E
M<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!C<F5A=&EO;B!O9B!P<FEV871E
M(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````
M+64``"TM``!54T52`````%5315).04U%`````%1%35!$25(`5$U0`"]T;7``
M````3$1?3$E"4D%265]0051(`$Q)0E!!5$@`3$E"4D%265]0051(`````$19
M3$1?3$E"4D%265]0051(````4TA,24)?4$%42```(R$O=7-R+V)I;B]P97)L
M"F5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PH@
M("`@:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"@IP86-K
M86=E(%]?<&%R7W!L.PH*(R`M+2T@5&AI<R!S8W)I<'0@;75S="!N;W0@=7-E
M(&%N>2!M;V1U;&5S(&%T(&-O;7!I;&4@=&EM92`M+2T*(R!U<V4@<W1R:6-T
M.PH*(VQI;F4@,34X"@IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F
M:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PH@("`@<F5Q=6ER
M92!&:6QE.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@
M(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(&UY("1T;W!D:7(@/2!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PH@("`@;W5T<RAQ<7M296UO
M=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PH@("`@1FEL93HZ1FEN9#HZ
M9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P
M87)?=&5M<"D["B`@("!R;61I<B`D<&%R7W1E;7`["B`@("`C($1O;B=T(')E
M;6]V92!T;W!D:7(@8F5C875S92!T:&ES(&-A=7-E<R!A(')A8V4@=VET:"!O
M=&AE<B!A<'!S"B`@("`C('1H870@87)E('1R>6EN9R!T;R!S=&%R="X*"B`@
M("!I9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*("`@
M("`@("`C(%-O;65T:&EN9R!W96YT('=R;VYG('5N;&EN:VEN9R!T:&4@=&5M
M<&]R87)Y(&1I<F5C=&]R>2X@(%1H:7,*("`@("`@("`C('1Y<&EC86QL>2!H
M87!P96YS(&]N('!L871F;W)M<R!T:&%T(&1I<V%L;&]W('5N;&EN:VEN9R!S
M:&%R960*("`@("`@("`C(&QI8G)A<FEE<R!A;F0@97AE8W5T86)L97,@=&AA
M="!A<F4@:6X@=7-E+B!5;FQI;FL@=VET:"!A(&)A8VMG<F]U;F0*("`@("`@
M("`C('-H96QL(&-O;6UA;F0@<V\@=&AE(&9I;&5S(&%R92!N;R!L;VYG97(@
M:6X@=7-E(&)Y('1H:7,@<')O8V5S<RX*("`@("`@("`C($1O;B=T(&1O(&%N
M>71H:6YG(&]N(%=I;F1O=W,@8F5C875S92!O=7(@<&%R96YT('!R;V-E<W,@
M=VEL;`H@("`@("`@(",@=&%K92!C87)E(&]F(&-L96%N:6YG('1H:6YG<R!U
M<"X*"B`@("`@("`@;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`H@("`@("`@
M("`@("!414U03$%412`]/B`G=&UP6%A86%@G+`H@("`@("`@("`@("!$25(@
M/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"B`@("`@("`@
M("`@(%-51D9)6"`]/B`G+F-M9"<L"B`@("`@("`@("`@(%5.3$E.2R`]/B`P
M+`H@("`@("`@("D["@H@("`@("`@('!R:6YT("1T;7`@(B,A+V)I;B]S:`IX
M/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PH@("!R;2`M<F8@)R1P87)?
M=&5M<"<*("`@:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"B`@("`@
M("!B<F5A:PH@("!F:0H@("!S;&5E<"`Q"B`@('@]8&5X<'(@7"1X("L@,6`*
M9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*("`@("`@("`@
M("`@8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*("`@("`@("!M>2`D8VUD
M(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*("`@
M("`@("!C;&]S92`D=&UP.PH@("`@("`@('-Y<W1E;2@D8VUD*3L*("`@("`@
M("!O=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O
M<FT@8VQE86YU<#H@*0H@("`@("`@("`@("`@+B`D=&UP+3YF:6QE;F%M92D[
M"B`@("!]"GT@?0H*0D5'24X@>PH@("`@26YT97)N86QS.CI005(Z.D)/3U0H
M*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*"B`@("!E=F%L
M('L*"E]P87)?:6YI=%]E;G8H*3L*"FEF("AE>&ES=',@)$5.5GM005)?05)'
M5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*("`@($!!4D=6(#T@;6%P
M("1%3E9[(E!!4E]!4D=67R1?(GTL("@Q("XN("1%3E9[4$%27T%21T-]("T@
M,2D["B`@("`D,"`]("1%3E9[4$%27T%21U9?,'T["GT*96QS92!["B`@("!F
M;W(@*&ME>7,@)45.5BD@>PH@("`@("`@(&1E;&5T92`D14Y6>R1??2!I9B`O
M7E!!4E]!4D=67R\["B`@("!]"GT*"FUY("1Q=6EE="`]("$D14Y6>U!!4E]$
M14)51WT["@HC(&9I>"`D<')O9VYA;64@:68@:6YV;VME9"!F<F]M(%!!5$@*
M;7D@)4-O;F9I9R`]("@*("`@('!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-
M4U=I;B\@/R`G.R<@.B`G.B<I+`H@("`@7V5X92`@("`@("`@/3X@*"1>3R`]
M?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*("`@
M(%]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z
M("<O)RDL"BD["@I?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*
M"B,@36%G:6,@<W1R:6YG(&-H96-K:6YG(&%N9"!E>'1R86-T:6YG(&)U;F1L
M960@;6]D=6QE<R![>WL*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*
M("`@(&QO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PH*("`@(",@0VAE
M8VL@9FEL92!T>7!E+"!G970@<W1A<G0@;V8@9&%T82!S96-T:6]N('M[>PH@
M("`@;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["B`@("!B:6YM
M;V1E*%]&2"D["@H@("`@;7D@)&)U9CL*("`@('-E96L@7T9(+"`M."P@,CL*
M("`@(')E860@7T9(+"`D8G5F+"`X.PH@("`@;&%S="!U;FQE<W,@)&)U9B!E
M<2`B7&Y005(N<&U<;B(["@H@("`@<V5E:R!?1D@L("TQ,BP@,CL*("`@(')E
M860@7T9(+"`D8G5F+"`T.PH@("`@<V5E:R!?1D@L("TQ,B`M('5N<&%C:R@B
M3B(L("1B=68I+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#0["@H@("`@)&1A
M=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["B`@("`C('U]?0H*("`@(",@17AT
M<F%C=&EN9R!E86-H(&9I;&4@:6YT;R!M96UO<GD@>WM["B`@("!M>2`E<F5Q
M=6ER95]L:7-T.PH@("`@=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["B`@("`@
M("`@<F5A9"!?1D@L("1B=68L(#0["B`@("`@("`@<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PH*("`@("`@("!M>2`D9G5L;&YA;64@/2`D
M8G5F.PH@("`@("`@(&]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M
M92(N+BXI*3L*("`@("`@("!M>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>
M*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PH@("`@("`@(&UY("@D
M8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN
M*BE\*3L*"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("`@("`@<F5A
M9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PH*("`@("`@("!I9B`H
M9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD
M+VDI('L*("`@("`@("`@("`@;7D@*"1O=70L("1F:6QE;F%M92D@/2!?=&5M
M<&9I;&4H)&5X="P@)&-R8RD["B`@("`@("`@("`@(&EF("@D;W5T*2!["B`@
M("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("`@("`@
M<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*
M("`@("`@("`@("`@("`@(&-H;6]D(#`W-34L("1F:6QE;F%M93L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F
M=6QL;F%M97T@/2`D9FEL96YA;64["B`@("`@("`@("`@("1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*("`@("`@("!]
M"B`@("`@("`@96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N
M9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PH@("`@("`@("`@("`C('-H
M;W5L9"!B92!M;W9E9"!T;R!?=&5M<&9I;&4H*0H@("`@("`@("`@("!M>2`D
M9FEL96YA;64@/2`B)$5.5GM005)?5$5-4'TO)&)A<V5N86UE)&5X="(["B`@
M("`@("`@("`@(&]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PH@("`@("`@
M("`@("!O<&5N(&UY("1O=70L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*
M("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@<')I;G0@
M)&]U="`D8G5F.PH@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@('T*
M("`@("`@("!E;'-E('L*("`@("`@("`@("`@)')E<75I<F5?;&ES='LD9G5L
M;&YA;65](#T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE
M>R1F=6QL;F%M97T@/2!["B`@("`@("`@("`@("`@("!B=68@/3X@)&)U9BP*
M("`@("`@("`@("`@("`@(&-R8R`]/B`D8W)C+`H@("`@("`@("`@("`@("`@
M;F%M92`]/B`D9G5L;&YA;64L"B`@("`@("`@("`@('T["B`@("`@("`@?0H@
M("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@?0H@("`@(R!]?7T*"B`@
M("!L;V-A;"!`24Y#(#T@*'-U8B!["B`@("`@("`@;7D@*"1S96QF+"`D;6]D
M=6QE*2`]($!?.PH*("`@("`@("!R971U<FX@:68@<F5F("1M;V1U;&4@;W(@
M(21M;V1U;&4["@H@("`@("`@(&UY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*("`@("`@("`@("`@;7D@)&ME
M>3L*("`@("`@("`@("`@9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2![
M"B`@("`@("`@("`@("`@("!N97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*
M("`@("`@("`@("`@("`@("1K97D@/2`D7SL@;&%S=#L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D
M969I;F5D*"1K97DI.PH@("`@("`@('T@;W(@<F5T=7)N.PH*("`@("`@("`D
M24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PH*
M("`@("`@("!I9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ
M1FEL93HZ;F5W*2D@>PH@("`@("`@("`@("!M>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W7W1M<&9I;&4@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1F
M:"D["B`@("`@("`@("`@('!R:6YT("1F:"`D9FEL96YA;64M/GMB=69].PH@
M("`@("`@("`@("!S965K*"1F:"P@,"P@,"D["B`@("`@("`@("`@(')E='5R
M;B`D9F@["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("!M
M>2`H)&]U="P@)&YA;64I(#T@7W1E;7!F:6QE*"<N<&TG+"`D9FEL96YA;64M
M/GMC<F-]*3L*("`@("`@("`@("`@:68@*"1O=70I('L*("`@("`@("`@("`@
M("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@("`@("!P<FEN="`D;W5T
M("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@("`@("!C;&]S92`D;W5T
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&]P96X@;7D@)&9H+"`G/"<L
M("1N86UE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@
M("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*"B`@("`@("`@9&EE
M(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<
M;B(["B`@("!]+"!`24Y#*3L*"B`@("`C($YO=R!L;V%D(&%L;"!B=6YD;&5D
M(&9I;&5S('M[>PH*("`@(",@:6YI=&EA;&EZ92!S:&%R960@;V)J96-T('!R
M;V-E<W-I;F<*("`@(')E<75I<F4@6%-,;V%D97(["B`@("!R97%U:7)E(%!!
M4CHZ2&5A=GD["B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["B`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["@H@("`@(R!N;W<@;&5T)W,@=')Y(&=E='1I;F<@:&5L<&5R
M(&UO9'5L97,@9G)O;2!W:71H:6X*("`@(')E<75I<F4@24\Z.D9I;&4["@H@
M("`@(R!L;V%D(')E<W0@;V8@=&AE(&=R;W5P(&EN"B`@("!W:&EL92`H;7D@
M)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PH@
M("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>
M3R!N92`G35-7:6XS,B<["B`@("`@("`@=6YL97-S("@D24Y#>R1F:6QE;F%M
M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["B`@("`@("`@("`@(",@
M<F5Q=6ER92!M;V1U;&5S+"!D;R!O=&AE<B!E>&5C=71A8FQE(&9I;&5S"B`@
M("`@("`@("`@(&EF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PH@("`@
M("`@("`@("`@("`@<F5Q=6ER92`D9FEL96YA;64["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("`C(%-K:7`@06-T
M:79E4W1A=&4G<R!S:71E8W5S=&]M:7IE+G!L(&9I;&4Z"B`@("`@("`@("`@
M("`@("!D;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U
M<W1O;6EZ95PN<&PD+SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("!D96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PH@("`@?0H*("`@
M(",@?7U]"@H@("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"([
M"B`@("`D<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*(R!]?7T*"B,@
M07)G=6UE;G0@<')O8V5S<VEN9R![>WL*;7D@0'!A<E]A<F=S.PIM>2`H)&]U
M="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["@ID96QE=&4@)$5.
M5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@
M<V5C=7)I='D@<')O8FQE;2D*"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%2
M7T1%0E5'?3L*(R!$;VXG="!S=V%L;&]W(&%R9W5M96YT<R!F;W(@8V]M<&EL
M960@97AE8W5T86)L97,@=VET:&]U="`M+7!A<BUO<'1I;VYS"FEF("@A)'-T
M87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H
M:69T*2D@>PH@("`@;7D@)61I<W1?8VUD(#T@<7<H"B`@("`@("`@<"`@(&)L
M:6)?=&]?<&%R"B`@("`@("`@:2`@(&EN<W1A;&Q?<&%R"B`@("`@("`@=2`@
M('5N:6YS=&%L;%]P87(*("`@("`@("!S("`@<VEG;E]P87(*("`@("`@("!V
M("`@=F5R:69Y7W!A<@H@("`@*3L*"B`@("`C(&EF('1H92!A<'`@:7,@:6YV
M;VME9"!A<R`B87!P;F%M92`M+7!A<BUO<'1I;VYS("TM<F5U<V4@4%)/1U)!
M32!`4%)/1U]!4D=6(BP*("`@(",@=7-E('1H92!A<'`@=&\@<G5N('1H92!G
M:79E;B!P97)L(&-O9&4@:6YS=&5A9"!O9B!A;GET:&EN9R!F<F]M('1H90H@
M("`@(R!A<'`@:71S96QF("AB=70@<W1I;&P@<V5T('5P('1H92!N;W)M86P@
M87!P(&5N=FER;VYM96YT(&%N9"!`24Y#*0H@("`@:68@*$!!4D=6(&%N9"`D
M05)'5ELP72!E<2`G+2UR975S92<I('L*("`@("`@("!S:&EF="!`05)'5CL*
M("`@("`@("`D14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["B`@
M("!]"B`@("!E;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*"B`@("`@
M("`@;7D@0&%D9%]T;U]I;F,["B`@("`@("`@=VAI;&4@*$!!4D=6*2!["B`@
M("`@("`@("`@("1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N
M*BDO(&]R(&QA<W0["@H@("`@("`@("`@("!I9B`H)#$@97$@)TDG*2!["B`@
M("`@("`@("`@("`@("!P=7-H($!A9&1?=&]?:6YC+"`D,CL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)TTG*2!["B`@("`@("`@
M("`@("`@("!E=F%L(")U<V4@)#(B.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&5L<VEF("@D,2!E<2`G02<I('L*("`@("`@("`@("`@("`@('5N<VAI
M9G0@0'!A<E]A<F=S+"`D,CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E
M;'-I9B`H)#$@97$@)T\G*2!["B`@("`@("`@("`@("`@("`D;W5T(#T@)#([
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=B)RD@
M>PH@("`@("`@("`@("`@("`@)&)U;F1L92`]("=S:71E)SL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T(G*2!["B`@("`@("`@
M("`@("`@("`D8G5N9&QE(#T@)V%L;"<["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@96QS:68@*"0Q(&5Q("=Q)RD@>PH@("`@("`@("`@("`@("`@)'%U
M:65T(#T@,3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@
M97$@)TPG*2!["B`@("`@("`@("`@("`@("!O<&5N("1L;V=F:"P@(CX^(BP@
M)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G5"<I('L*("`@("`@
M("`@("`@("`@("1C86-H95]N86UE(#T@)#(["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@('-H:69T*$!!4D=6*3L*"B`@("`@("`@("`@(&EF("AM>2`D
M8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PH@("`@("`@("`@("`@("`@9&5L971E
M("1%3E9[)U!!4E]414U0)WT["B`@("`@("`@("`@("`@("!I;FET7VEN8R@I
M.PH@("`@("`@("`@("`@("`@<F5Q=6ER92!005(Z.D1I<W0["B`@("`@("`@
M("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*
M("`@("`@("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@
M0$%21U8["B`@("`@("`@("`@("`@("!E>&ET.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!U;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PH@
M("`@?0I]"@HC(%A86"`M+2!A9&0@+2UP87(M9&5B=6<@<W5P<&]R="$*"B,@
M?7U]"@HC($]U='!U="!M;V1E("@M3RD@:&%N9&QI;F<@>WM["FEF("@D;W5T
M*2!["B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&
M24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E($E/
M.CI&:6QE.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@?0H*
M("`@(&UY("1P87(@/2!S:&EF="A`05)'5BD["B`@("!M>2`D>FEP.PH*"B`@
M("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!M>2`D9F@L("<\
M)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PH@("`@
M("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("!B;&5S<R@D9F@L("=)3SHZ1FEL
M92<I.PH*("`@("`@("`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("`@
M("`@*"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"D@*0H@("`@("`@("`@("!O<B!D:64@(E)E
M860@)R1P87(G(&5R<F]R.B`D(2(["B`@("!]"@H*("`@(&UY("5E;G8@/2!D
M;R!["B`@("`@("`@:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N
M=&5N=',H)TU%5$$N>6UL)RDI('L*("`@("`@("`@("`@)&UE=&$@/7X@<R\N
M*EYP87(Z)"\O;7,["B`@("`@("`@("`@("1M971A(#U^(',O7EQ3+BHO+VUS
M.PH@("`@("`@("`@("`D;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<[
M"B`@("`@("`@?0H@("`@?3L*"B`@("`C($]P96X@:6YP=70@86YD(&]U='!U
M="!F:6QE<R![>WL*("`@(&QO8V%L("0O(#T@7#0["@H@("`@:68@*&1E9FEN
M960@)'!A<BD@>PH@("`@("`@(&]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE
M("(D(3H@)'!A<B(["B`@("`@("`@8FEN;6]D92A005(I.PH@("`@("`@(&1I
M92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")0
M2UPP,#-<,#`T(CL*("`@('T*"B`@("!#<F5A=&50871H*"1O=70I(#L*("`@
M(`H@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*("`@("`@("`D;W5T+`H@
M("`@("`@($E/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].
M3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"B`@("`@("`@,#<W-RP*("`@
M("D@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH*("`@("0O(#T@*&1E
M9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*("`@('-E
M96L@7T9(+"`P+"`P.PH@("`@;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*
M("`@(&EF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>
M*#\Z(R%\7$!R96TI+RD@>PH@("`@("`@(')E<75I<F4@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP.PH@("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W
M+3YA<'!L>2A<)&QO861E<BP@)#`I"B`@("!]"B`@("!F;W)E86-H(&UY("1K
M97D@*'-O<G0@:V5Y<R`E96YV*2!["B`@("`@("`@;7D@)'9A;"`]("1E;G9[
M)&ME>7T@;W(@;F5X=#L*("`@("`@("`D=F%L(#T@979A;"`D=F%L(&EF("1V
M86P@/7X@+UY;)R)=+SL*("`@("`@("!M>2`D;6%G:6,@/2`B7U]%3E9?4$%2
M7R(@+B!U8R@D:V5Y*2`N(")?7R(["B`@("`@("`@;7D@)'-E="`](")005)?
M(B`N('5C*"1K97DI("X@(CTD=F%L(CL*("`@("`@("`D;&]A9&5R(#U^('-[
M)&UA9VEC*"`K*7U["B`@("`@("`@("`@("1M86=I8R`N("1S970@+B`H)R`G
M('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0H@("`@("`@('UE9SL*
M("`@('T*("`@("1F:"T^<')I;G0H)&QO861E<BD["B`@("`D+R`]('5N9&5F
M.PH@("`@(R!]?7T*"B`@("`C(%=R:71E(&)U;F1L960@;6]D=6QE<R![>WL*
M("`@(&EF("@D8G5N9&QE*2!["B`@("`@("`@<F5Q=6ER92!005(Z.DAE879Y
M.PH@("`@("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*("`@
M("`@("!I;FET7VEN8R@I.PH*("`@("`@("!R97%U:7)E7VUO9'5L97,H*3L*
M"B`@("`@("`@;7D@0&EN8R`]('-O<G0@>PH@("`@("`@("`@("!L96YG=&@H
M)&(I(#P]/B!L96YG=&@H)&$I"B`@("`@("`@?2!G<F5P('L*("`@("`@("`@
M("`@(2]"4T1004XO"B`@("`@("`@?2!G<F5P('L*("`@("`@("`@("`@*"1B
M=6YD;&4@;F4@)W-I=&4G*2!O<@H@("`@("`@("`@("`H)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`H@("`@("`@("`@("`@)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*("`@("`@("!]($!)3D,[
M"@H@("`@("`@(",@1FEL92!E>&ES=',@=&5S="!A9&1E9"!T;R!F:7@@4E0@
M(S0Q-SDP.@H@("`@("`@(",@1G5N;GDL(&YO;BUE>&ES=&EN9R!E;G1R>2!I
M;B!?/"XN+BYA=71O+T-O;7!R97-S+U)A=R]:;&EB+V%U=&]S<&QI="YI>"X*
M("`@("`@("`C(%1H:7,@:7,@82!B86YD+6%I9"!F:7@@=VET:"!N;R!D965P
M97(@9W)A<W`@;V8@=&AE(&ES<W5E+@H@("`@("`@(",@4V]M96)O9'D@<&QE
M87-E(&=O('1H<F]U9V@@=&AE('!A:6X@;V8@=6YD97)S=&%N9&EN9R!W:&%T
M)W,@:&%P<&5N:6YG+`H@("`@("`@(",@22!F86EL960N("TM(%-T969F96X*
M("`@("`@("!M>2`E9FEL97,["B`@("`@("`@+UY?/"@N*RDD+R!A;F0@+64@
M)#$@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y<R`E.CH["B`@("`@("`@)&9I
M;&5S>R1??2LK(&9O<B!V86QU97,@)4E.0SL*"B`@("`@("`@;7D@)&QI8E]E
M>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["B`@("`@("`@;7D@)7=R
M:71T96X["@H@("`@("`@(&9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*
M("`@("`@("`@("`@;7D@*"1N86UE+"`D9FEL92D["@H@("`@("`@("`@("!F
M;W)E86-H(&UY("1D:7(@*$!I;F,I('L*("`@("`@("`@("`@("`@(&EF("@D
M;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B`@("`@("`@
M("`@("`@("`@("`@)&9I;&4@/2`D7SL*("`@("`@("`@("`@("`@("`@("!L
M87-T.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS:68@
M*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PH@("`@("`@("`@("`@
M("`@("`@("@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["B`@("`@("`@("`@
M("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@(&5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ
M.DUO9'5L94-A8VAE>R0Q?2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`H
M)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["B`@("`@("`@("`@("`@("`@
M("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@(&5L<VEF("@M9B`B)&1I<B\D,2(I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!N97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R
M:71T96Y[)&YA;65]*RL["B`@("`@("`@("`@(&YE>'0@:68@(7)E9B@D9FEL
M92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PH@("`@("`@("`@
M("!O=71S*"!J;VEN("(B+`H@("`@("`@("`@("`@("`@<7$H4&%C:VEN9R`B
M*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`H@("`@("`@
M("`@("`@("`@<7$H(BXN+BD*("`@("`@("`@("`@*3L*"B`@("`@("`@("`@
M(&UY("1C;VYT96YT.PH@("`@("`@("`@("!I9B`H<F5F*"1F:6QE*2D@>PH@
M("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("!O
M<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE
M.B`D(2(["B`@("`@("`@("`@("`@("!B:6YM;V1E*$9)3$4I.PH@("`@("`@
M("`@("`@("`@)&-O;G1E;G0@/2`\1DE,13X["B`@("`@("`@("`@("`@("!C
M;&]S92!&24Q%.PH*("`@("`@("`@("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13
M=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0H@("`@("`@("`@
M("`@("`@("`@(&EF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^
M("]<+B@_.G!M?&EX?&%L*20O:3L*"B`@("`@("`@("`@("`@("!005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4L("1N86UE*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@;W5T<RAQ
M<2A7<FET=&5N(&%S("(D;F%M92(I*3L*("`@("`@("`@("`@)&9H+3YP<FEN
M="@B1DE,12(I.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L
M96YG=&@H)&YA;64I("L@.2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'-P
M<FEN=&8H"B`@("`@("`@("`@("`@("`B)3`X>"\E<R(L($%R8VAI=F4Z.EII
M<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64*("`@("`@("`@("`@
M*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D
M8V]N=&5N="DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@D8V]N=&5N="D[
M"B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*"B`@("`C($YO=R!W<FET92!O
M=70@=&AE(%!!4B!A;F0@;6%G:6,@<W1R:6YG<R![>WL*("`@("1Z:7`M/G=R
M:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*"B`@("`D8V%C:&5?;F%M
M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["B`@("!I9B`H(21C86-H
M95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*("`@
M("`@("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I
M9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@
M("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ
M340U+3YN97<@?3L*"B`@("`@("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@
M1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@(&UY("1S:&%?=F5R
M<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@
M("`@("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R
M<VEO;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@)&-T>"T^861D9FEL92@D
M;W5T+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("!]"B`@("`@("`@96QS92![
M"B`@("`@("`@("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T
M(BDI('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@
M("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@(&-L
M;W-E*"1F:"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1C
M86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*
M("`@('T*("`@("1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@
M)&-A8VAE7VYA;64I.PH@("`@)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*("`@
M("1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PH@("`@)&9H+3YP<FEN="AP86-K
M*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B`@("`D9F@M
M/G!R:6YT*")<;E!!4BYP;5QN(BD["B`@("`D9F@M/F-L;W-E.PH@("`@8VAM
M;V0@,#<U-2P@)&]U=#L*("`@(",@?7U]"@H@("`@97AI=#L*?0HC('U]?0H*
M(R!0<F5P87)E("1P<F]G;F%M92!I;G1O(%!!4B!F:6QE(&-A8VAE('M[>PI[
M"B`@("!L87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["@H@("`@7V9I
M>%]P<F]G;F%M92@I.PH*("`@(",@3F]W(&QO860@=&AE(%!!4B!F:6QE(&%N
M9"!P=70@:70@:6YT;R!005(Z.DQI8D-A8VAE('M[>PH@("`@<F5Q=6ER92!0
M05(["B`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H*("`@
M('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I
M9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@1FEL93HZ1FEN
M9#L*("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@('T*("`@(&UY
M("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@(&UY("1F:"`]($E/.CI&
M:6QE+3YN97<["B`@("`D9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O
M<B!D:64@(B0A.B`D0"(["B`@("`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H
M)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D
M:64@(B0A.B`D0"(["@H@("`@<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*
M("`@("1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PH*("`@("1Q
M=6EE="`]("$D14Y6>U!!4E]$14)51WT["B`@("!O=71S*'%Q*%PD14Y6>U!!
M4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*"B`@("!I9B`H9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P
M;VEN="$*("`@("`@("!F;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB
M97)S("D@>PH@("`@("`@("`@("!N97AT(&EF("1M96UB97(M/FES1&ER96-T
M;W)Y.PH@("`@("`@("`@("!M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF
M:6QE3F%M93L*("`@("`@("`@("`@;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE
M(#U^(&U["B`@("`@("`@("`@("`@("!>"B`@("`@("`@("`@("`@("`O/W-H
M;&EB+PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I
M;VY]+RD_"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[87)C
M:&YA;65]+RD_"B`@("`@("`@("`@("`@("`H6UXO72LI"B`@("`@("`@("`@
M("`@("`D"B`@("`@("`@("`@('UX.PH@("`@("`@("`@("!M>2`D97AT<F%C
M=%]N86UE(#T@)#$["B`@("`@("`@("`@(&UY("1D97-T7VYA;64@/2!&:6QE
M.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE
M*3L*("`@("`@("`@("`@:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D
M;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*("`@("`@("`@("`@("`@
M(&]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR
M96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("!O=71S*'%Q*$5X=')A8W1I;F<@(B1M
M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B`@("`@("`@("`@("`@
M("`D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["B`@
M("`@("`@("`@("`@("!C:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@
M97$@(FAP=7@B.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H@("`@
M(R!]?7T*?0HC('U]?0H*(R!)9B!T:&5R92=S(&YO(&UA:6XN<&P@=&\@<G5N
M+"!S:&]W('5S86=E('M[>PIU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G
M;F%M97TI('L*("`@(&1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@
M)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C
M+G!A<B!=(%L@<')O9W)A;2YP;"!="B`@("`@("`D,"!;("U"?"UB(%T@6RU/
M;W5T9FEL95T@<W)C+G!A<@HN"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D
M<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0HC('U]?0H*<W5B($-R
M96%T95!A=&@@>PH@("`@;7D@*"1N86UE*2`]($!?.PH@("`@"B`@("!R97%U
M:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@;7D@*"1B87-E;F%M92P@)'!A=&@L
M("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<
M+BXJ)RDI.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.E!A=&@["B`@("`*("`@
M($9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@
M(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*"G-U8B!R97%U:7)E7VUO9'5L
M97,@>PH@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@
M)%Y/(&YE("=-4U=I;C,R)SL*"B`@("!R97%U:7)E(&QI8CL*("`@(')E<75I
M<F4@1'EN84QO861E<CL*("`@(')E<75I<F4@:6YT96=E<CL*("`@(')E<75I
M<F4@<W1R:6-T.PH@("`@<F5Q=6ER92!W87)N:6YG<SL*("`@(')E<75I<F4@
M=F%R<SL*("`@(')E<75I<F4@0V%R<#L*("`@(')E<75I<F4@0V%R<#HZ2&5A
M=GD["B`@("!R97%U:7)E($5R<FYO.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ
M2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R.PH@("`@<F5Q=6ER92!&8VYT
M;#L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ
M4W!E8SL*("`@(')E<75I<F4@6%-,;V%D97(["B`@("!R97%U:7)E($-O;F9I
M9SL*("`@(')E<75I<F4@24\Z.DAA;F1L93L*("`@(')E<75I<F4@24\Z.D9I
M;&4["B`@("!R97%U:7)E($-O;7!R97-S.CI:;&EB.PH@("`@<F5Q=6ER92!!
M<F-H:79E.CI::7`["B`@("!R97%U:7)E(%!!4CL*("`@(')E<75I<F4@4$%2
M.CI(96%V>3L*("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("!R97%U:7)E(%!!4CHZ1FEL=&5R
M.CI0871C:$-O;G1E;G0["B`@("!R97%U:7)E(&%T=')I8G5T97,["B`@("!E
M=F%L('L@<F5Q=6ER92!#=V0@?3L*("`@(&5V86P@>R!R97%U:7)E(%=I;C,R
M('T["B`@("!E=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*("`@(&5V
M86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PH@("`@979A
M;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*("`@(&5V
M86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!]
M.PI]"@HC(%1H92!#('9E<G-I;VX@;V8@=&AI<R!C;V1E(&%P<&5A<G,@:6X@
M;7EL9'(O;6MT;7!D:7(N8PHC(%1H:7,@8V]D92!A;'-O(&QI=F5S(&EN(%!!
M4CHZ4V5T=7!496UP(&%S('-E=%]P87)?=&5M<%]E;G8A"G-U8B!?<V5T7W!A
M<E]T96UP('L*("`@(&EF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*("`@("`@("`D<&%R7W1E;7`@
M/2`D,3L*("`@("`@("!R971U<FX["B`@("!]"@H@("`@9F]R96%C:"!M>2`D
M<&%T:"`H"B`@("`@("`@*&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@
M5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"B`@("`@("`@<7<H($,Z7%Q4
M14U0("]T;7`@+B`I"B`@("`I('L*("`@("`@("!N97AT('5N;&5S<R!D969I
M;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["B`@("`@("`@
M;7D@)'5S97)N86UE.PH@("`@("`@(&UY("1P=W5I9#L*("`@("`@("`C(&1O
M97,@;F]T('=O<FL@979E<GEW:&5R93H*("`@("`@("!E=F%L('LH)'!W=6ED
M*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["@H@("`@("`@(&EF
M("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B`@("`@("`@("`@
M("1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PH@("`@("`@('T*("`@
M("`@("!E;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*("`@("`@("`@("`@)'5S
M97)N86UE(#T@)'!W=6ED.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@
M("`@("`@("`@)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM5
M4T52?2!\?"`G4UE35$5-)SL*("`@("`@("!]"B`@("`@("`@)'5S97)N86UE
M(#U^(',O7%<O7R]G.PH*("`@("`@("!M>2`D<W1M<&1I<B`]("(D<&%T:"1#
M;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PH@
M("`@("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&EF("@A)$5.
M5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I
M*5LY72D@>PH@("`@("`@("`@("!O<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N
M86UE*3L*("`@("`@("`@("`@<V5E:R`D9F@L("TQ."P@,CL*("`@("`@("`@
M("`@<WES<F5A9"`D9F@L(&UY("1B=68L(#8["B`@("`@("`@("`@(&EF("@D
M8G5F(&5Q(")<,$-!0TA%(BD@>PH@("`@("`@("`@("`@("`@<V5E:R`D9F@L
M("TU."P@,CL*("`@("`@("`@("`@("`@('-Y<W)E860@)&9H+"`D8G5F+"`T
M,3L*("`@("`@("`@("`@("`@("1B=68@/7X@<R]<,"\O9SL*("`@("`@("`@
M("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@
M)&)U9CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@
M("`@("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(
M03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@("`@("`@("`@("`@
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M
M/FYE=R!]"B`@("`@("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@
M1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@("`@
M("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X
M(&%N9"`U+C,Y"B`@("`@("`@("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E
M=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@("`@
M("`@("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R
M<VEO;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@("`@("`@("`D8W1X+3YA
M9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@
M("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@
M("`@("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1S
M=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@
M)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("!]"B`@("`@("`@96QS92![
M"B`@("`@("`@("`@("1%3E9[4$%27T-,14%.?2`](#$["B`@("`@("`@("`@
M("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*("`@("`@
M("!]"@H@("`@("`@("1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["B`@("`@
M("`@;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@;&%S=#L*("`@('T*
M"B`@("`D<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.
M5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"@IS=6(@7W1E;7!F:6QE('L*("`@
M(&UY("@D97AT+"`D8W)C*2`]($!?.PH@("`@;7D@*"1F:"P@)&9I;&5N86UE
M*3L*"B`@("`D9FEL96YA;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*"B`@
M("!I9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("`@("`@=6YL:6YK("1F:6QE
M;F%M92!I9B`M92`D9FEL96YA;64["B`@("`@("`@<'5S:"!`=&UP9FEL92P@
M)&9I;&5N86UE.PH@("`@?0H@("`@96QS92!["B`@("`@("`@<F5T=7)N("AU
M;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*("`@('T*"B`@
M("!O<&5N("1F:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@8FEN
M;6]D92@D9F@I.PH@("`@<F5T=7)N*"1F:"P@)&9I;&5N86UE*3L*?0H*(R!S
M86UE(&-O9&4@;&EV97,@:6X@4$%2.CI3971U<%!R;V=N86UE.CIS971?<')O
M9VYA;64*<W5B(%]S971?<')O9VYA;64@>PH@("`@:68@*&1E9FEN960@)$5.
M5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N
M*RDO*2!["B`@("`@("`@)'!R;V=N86UE(#T@)#$["B`@("!]"@H@("`@)'!R
M;V=N86UE('Q\/2`D,#L*"B`@("!I9B`H)$5.5GM005)?5$5-4'T@86YD(&EN
M9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*("`@("`@
M("`D<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N
M86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["B`@("!]"@H@("`@:68@*"$D
M14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG
M>U]D96QI;7TI(#X](#`I('L*("`@("`@("!I9B`H;W!E;B!M>2`D9F@L("<\
M)RP@)'!R;V=N86UE*2!["B`@("`@("`@("`@(')E='5R;B!I9B`M<R`D9F@[
M"B`@("`@("`@?0H@("`@("`@(&EF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?
M97AE?2(I('L*("`@("`@("`@("`@)'!R;V=N86UE("X]("1#;VYF:6=[7V5X
M97T["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"B`@("!]"@H@("`@
M9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%
M+RP@)$5.5GM0051(?2D@>PH@("`@("`@(&YE>'0@:68@97AI<W1S("1%3E9[
M4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PH@("`@("`@
M("1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PH@("`@("`@("@H
M)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N
M9FEG>U]E>&5](BDL(&QA<W0I"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B`@("`@("`@
M*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I
M+"!L87-T*0H@("`@("`@("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M92(["B`@("!]"GT*"G-U8B!?9FEX7W!R;V=N86UE('L*("`@
M("0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["B`@("!I
M9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PH@
M("`@("`@("1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE
M(CL*("`@('T*"B`@("`C(%A86"`M(&AA8VL@=&\@;6%K92!05T0@=V]R:PH@
M("`@;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E
M=&-W9"@I"B`@("`@("`@("`@("`@("`Z("@H9&5F:6YE9"`F5VEN,S(Z.D=E
M=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["B`@("!C:&]M<"@D
M<'=D*3L*("`@("1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?
M9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PH*("`@("1%3E9[4$%2
M7U!23T=.04U%?2`]("1P<F]G;F%M93L*?0H*<W5B(%]P87)?:6YI=%]E;G8@
M>PH@("`@:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PH@
M("`@("`@(')E='5R;CL*("`@('T@96QS92!["B`@("`@("`@)$5.5GM005)?
M24Y)5$E!3$E:141](#T@,CL*("`@('T*"B`@("!F;W(@*'%W*"!34$%73D5$
M(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@
M*2`I('L*("`@("`@("!D96QE=&4@)$5.5GLG4$%27R<N)%]].PH@("`@?0H@
M("`@9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PH@("`@
M("`@("1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@
M:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["B`@("!]"@H@("`@
M;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@
M("`@("(["@H@("`@:68@*"1%3E9[4$%27U1%35!]*2!["B`@("`@("`@9&5L
M971E("1%3E9[4$%27T-,14%.?3L*("`@('T*("`@(&5L<VEF("@A97AI<W1S
M("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*("`@("`@("!M>2`D=F%L=64@
M/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PH@
M("`@("`@("1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!
M4E]#3$5!3CTH7%,K*2\["B`@("!]"GT*"G-U8B!O=71S('L*("`@(')E='5R
M;B!I9B`D<75I970["B`@("!I9B`H)&QO9V9H*2!["B`@("`@("`@<')I;G0@
M)&QO9V9H(")`7UQN(CL*("`@('T*("`@(&5L<V4@>PH@("`@("`@('!R:6YT
M(")`7UQN(CL*("`@('T*?0H*<W5B(&EN:71?:6YC('L*("`@(')E<75I<F4@
M0V]N9FEG.PH@("`@<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N
M9FEG.CI#;VYF:6=[)%]]+"!Q=R@*("`@("`@("!A<F-H;&EB97AP('!R:79L
M:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`H@("`@("`@('9E;F1O<F%R
M8VAE>'`@=F5N9&]R;&EB97AP"B`@("`I.PI]"@HC(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,*(R!4:&4@;6%I;B!P86-K86=E(&9O<B!S8W)I<'0@97AE
M8W5T:6]N"@IP86-K86=E(&UA:6X["@IR97%U:7)E(%!!4CL*=6YS:&EF="!`
M24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD[
M"@ID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O
M9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"B`@("!U;FQE
M<W,@+64@)'!R;V=N86UE.PH*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q
M*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@
M)$`["@I].PH*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"@I#3U)%.CIE>&ET
M*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD[
M"F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["@HQ.PH*(VQI;F4@,3`Q
M,0H*7U]%3D1?7PH`8%;_?P$`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````99L``$V;`````````0````$````!````!0(```$`
M``!4`@```0```*<#```,````5)4```T```!TY```&0```/3.`0`;````!```
M`!H```#XS@$`'`````0```#U_O]OM($```4```!TC```!@```'2%```*````
M/P4```L````0````%0`````````#`````-`!``(````H`@``%````!$````7
M````+),``!$```#TD@``$@```#@````3````"````/[__V^4D@``____;P,`
M``#P__]OM)$`````````````````````````````````````````````````
M``````````````````#/`0```````````&"5``!@E0``8)4``&"5``!@E0``
M8)4``&"5``!@E0``8)4``&"5``!@E0``8)4``&"5``!@E0``8)4``&"5``!@
ME0``8)4``&"5``!@E0``8)4``&"5``!@E0``8)4``&"5``!@E0``8)4``&"5
M``!@E0``8)4``&"5``!@E0``8)4``&"5``!@E0``8)4``&"5``!@E0``8)4`
M`&"5``!@E0``8)4``&"5``!@E0``8)4``&"5``!@E0``8)4``&"5``!@E0``
M8)4``&"5``!@E0``8)4``&"5``!@E0``8)4``&"5``!@E0``8)4``&"5``!@
ME0``8)4``&"5``!@E0``8)4``&"5``!@E0``8)4``````````````````/__
M__^(Z```1T-#.B`H56)U;G1U+TQI;F%R;R`T+C@N,"TW=6)U;G1U,2D@-"XX
M+C``1T-#.B`H56)U;G1U+TQI;F%R;R`T+C<N,RTQ=6)U;G1U,2D@-"XW+C,`
M030```!A96%B:0`!*@````4W+4$`!@H'00@!"0(*!!($$P$4`14!%P,8`1D!
M&@(;`QP!(@$`+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T
M92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU
M+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`+G)E;"YP;'0`+FEN
M:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N05)-+F5X:61X`"YE:%]F<F%M90`N
M:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N:F-R`"YD>6YA;6EC`"YG;W0`+F1A
M=&$`+F)S<P`N8V]M;65N=``N05)-+F%T=')I8G5T97,`````````````````
M```````````````````````````````````````+`````0````(```!4@0``
M5`$``!D```````````````$`````````$P````<````"````<($``'`!```@
M```````````````$`````````"$````'`````@```)"!``"0`0``)```````
M````````!``````````T````]O__;P(```"T@0``M`$``,`#```%````````
M``0````$````/@````L````"````=(4``'0%````!P``!@````$````$````
M$````$8````#`````@```'2,``!T#```/P4``````````````0````````!.
M````____;P(```"TD0``M!$``.`````%``````````(````"````6P```/[_
M_V\"````E)(``)02``!@````!@````,````$`````````&H````)`````@``
M`/22``#T$@``.`````4`````````!`````@```!S````"0````(````LDP``
M+!,``"@"```%````#`````0````(````?`````$````&````5)4``%05```,
M```````````````$`````````'<````!````!@```&"5``!@%0``8`,`````
M````````!`````0```""`````0````8```#`F```P!@``+1+````````````
M``@`````````B`````$````&````=.0``'1D```(```````````````$````
M`````(X````!`````@```'SD``!\9```O%\`````````````!`````````"6
M`````0``<((````X1`$`.,0```@````-``````````0`````````H0````$`
M```"````0$0!`$#$```$```````````````$`````````*L````.`````P``
M`/3.`0#TS@``!```````````````!`````````"W````#P````,```#XS@$`
M^,X```0```````````````0`````````PP````$````#````_,X!`/S.```$
M```````````````$`````````,@````&`````P````#/`0``SP````$```8`
M````````!`````@```#1`````0````,`````T`$``-```"0!````````````
M``0````$````U@````$````#````)-$!`"31```0```````````````$````
M`````-P````(`````P```#C1`0`TT0``0!``````````````"`````````#A
M`````0```#``````````--$``%0```````````````$````!````Z@````,`
M`'```````````(C1```U```````````````!``````````$````#````````
M``````"]T0``^@```````````````0`````````!````8)4```````````P`
M!````'"5```````````,``$```!TE0``````````#``'````P)<`````````
M``P``0```,27```````````,``<````\F```````````#``!````0)@`````
M``````P`!P```&28```````````,``$```!HF```````````#``'````I)@`
C``````````P``0```*B8```````````,```D80`D9``D=```
